@@ -97,7 +97,10 @@ scenario = create_scenario(
 )
 scenario.execute({"algo": "fullfact", "n_samples": 25})
 scenario.post_process(
-    "ScatterPlotMatrix", variable_names=["x1", "x2", "y"], save=False, show=True
+    "ScatterPlotMatrix",
+    variable_names=["x1", "x2", "y"],
+    save=False,
+    show=True,
 )
 
 ##########################################################################
