@@ -31,7 +31,6 @@ from os import name as os_name
 from gemseo.api import configure_logger
 from gemseo.api import create_discipline
 from gemseo.api import create_mda
-from matplotlib import pyplot as plt
 
 IS_NT = os_name == "nt"
 
@@ -103,7 +102,9 @@ mda = create_mda(
 res = mda.execute()
 display_result(res, mda.name)
 mda.plot_residual_history(
-    n_iterations=10, logscale=[1e-8, 10.0], show=False, save=False, fig_size=(10, 2)
+    n_iterations=10,
+    logscale=[1e-8, 10.0],
+    save=False,
+    show=True,
+    fig_size=(10, 2),
 )
-# Workaround for HTML rendering, instead of ``show=True``
-plt.show()
