@@ -29,7 +29,6 @@ from __future__ import annotations
 from gemseo.api import configure_logger
 from gemseo.api import create_discipline
 from gemseo.api import create_mda
-from matplotlib import pyplot as plt
 
 configure_logger()
 
@@ -89,7 +88,9 @@ mda = create_mda("MDAChain", disciplines, inner_mda_name="MDAJacobi")
 res = mda.execute()
 display_result(res, mda.name)
 mda.plot_residual_history(
-    n_iterations=10, logscale=[1e-8, 10.0], show=False, save=False, fig_size=(10, 2)
+    n_iterations=10,
+    logscale=[1e-8, 10.0],
+    save=False,
+    show=True,
+    fig_size=(10, 2),
 )
-# Workaround for HTML rendering, instead of ``show=True``
-plt.show()
