@@ -34,7 +34,6 @@ from gemseo.api import configure_logger
 from gemseo.api import create_design_space
 from gemseo.api import create_discipline
 from gemseo.api import create_scenario
-from matplotlib import pyplot as plt
 
 configure_logger()
 
@@ -74,7 +73,7 @@ scenario = create_scenario(
 scenario.execute({"algo": "DiagonalDOE", "n_samples": 10})
 
 dataset = scenario.export_to_dataset(opt_naming=False)
-dataset.plot("ScatterMatrix", save=False, show=False)
+dataset.plot("ScatterMatrix", save=False, show=True)
 
 ###############################################################################
 # Sample with reverse mode for :math:`y`
@@ -94,6 +93,4 @@ scenario.execute(
 )
 
 dataset = scenario.export_to_dataset(opt_naming=False)
-dataset.plot("ScatterMatrix", save=False, show=False)
-# Workaround for HTML rendering, instead of ``show=True``
-plt.show()
+dataset.plot("ScatterMatrix", save=False, show=True)
