@@ -36,7 +36,6 @@ from gemseo.problems.aerostructure.aerostructure_design_space import (
     AerostructureDesignSpace,
 )
 from gemseo.problems.scalable.data_driven.problem import ScalableProblem
-from matplotlib import pyplot as plt
 
 configure_logger()
 
@@ -133,6 +132,4 @@ scenario.execute({"algo": "NLOPT_SLSQP", "max_iter": 100})
 ###############################################################################
 # We can post-process the results.
 # Here, we use the standard :class:`.OptHistoryView`.
-scenario.post_process("OptHistoryView", save=False, show=False)
-# Workaround for HTML rendering, instead of ``show=True``
-plt.show()
+scenario.post_process("OptHistoryView", save=False, show=True)
