@@ -26,77 +26,53 @@ from __future__ import annotations
 
 import pprint
 
-from gemseo.algos.parameter_space import ParameterSpace
-from gemseo.api import create_discipline
 from gemseo.uncertainty.sensitivity.morris.analysis import MorrisAnalysis
-from matplotlib import pyplot as plt
-from numpy import pi
+from gemseo.uncertainty.use_cases.ishigami.ishigami_discipline import IshigamiDiscipline
+from gemseo.uncertainty.use_cases.ishigami.ishigami_space import IshigamiSpace
 
-#######################################################################################
+# %%
 # In this example,
-# we consider a function from :math:`[-\pi,\pi]^3` to :math:`\mathbb{R}^3`:
+# we consider the Ishigami function :cite:`ishigami1990`
 #
 # .. math::
 #
-#    (y_1,y_2)=\left(f(x_1,x_2,x_3),f(x_2,x_1,x_3)\right)
+#    f(x_1,x_2,x_3)=\sin(x_1)+7\sin(x_2)^2+0.1x_3^4\sin(x_1)
 #
-# where :math:`f(a,b,c)=\sin(a)+7\sin(b)^2+0.1*c^4\sin(a)` is the Ishigami function:
+# implemented as an :class:`.MDODiscipline` by the :class:`.IshigamiDiscipline`.
+# It is commonly used
+# with the independent random variables :math:`X_1`, :math:`X_2` and :math:`X_3`
+# uniformly distributed between :math:`-\pi` and :math:`\pi`
+# and defined in the :class:`.IshigamiSpace`.
 
-expressions = {
-    "y1": "sin(x1)+7*sin(x2)**2+0.1*x3**4*sin(x1)",
-    "y2": "sin(x2)+7*sin(x1)**2+0.1*x3**4*sin(x2)",
-}
-discipline = create_discipline(
-    "AnalyticDiscipline", expressions=expressions, name="Ishigami2"
-)
+discipline = IshigamiDiscipline()
+uncertain_space = IshigamiSpace()
 
-#######################################################################################
+# %%
 # Then,
-# we consider the case where
-# the deterministic variables :math:`x_1`, :math:`x_2` and :math:`x_3` are replaced
-# with the uncertain variables :math:`X_1`, :math:`X_2` and :math:`X_3`.
-# The latter are independent and identically distributed
-# according to a uniform distribution between :math:`-\pi` and :math:`\pi`:
-space = ParameterSpace()
-for variable in ["x1", "x2", "x3"]:
-    space.add_random_variable(
-        variable, "OTUniformDistribution", minimum=-pi, maximum=pi
-    )
-
-#######################################################################################
-# From that,
-# we would like to carry out a sensitivity analysis with the random outputs
-# :math:`Y_1=f(X_1,X_2,X_3)` and :math:`Y_2=f(X_2,X_1,X_3)`.
-# For that,
-# we can compute the correlation coefficients from a :class:`.MorrisAnalysis`:
-morris = MorrisAnalysis([discipline], space, 10)
-morris.compute_indices()
+# we run sensitivity analysis of type :class:`.MorrisAnalysis`:
+sensitivity_analysis = MorrisAnalysis([discipline], uncertain_space, 10)
+sensitivity_analysis.compute_indices()
 
 #######################################################################################
 # The resulting indices are the empirical means and the standard deviations
 # of the absolute output variations due to input changes.
-pprint.pprint(morris.indices)
+pprint.pprint(sensitivity_analysis.indices)
 
 #######################################################################################
 # The main indices corresponds to these empirical means
 # (this main method can be changed with :attr:`.MorrisAnalysis.main_method`):
-pprint.pprint(morris.main_indices)
+pprint.pprint(sensitivity_analysis.main_indices)
 
 #######################################################################################
 # and can be interpreted with respect to the empirical bounds of the outputs:
-pprint.pprint(morris.outputs_bounds)
+pprint.pprint(sensitivity_analysis.outputs_bounds)
 
 #######################################################################################
-# We can also sort the input parameters by decreasing order of influence
-# and observe that this ranking is not the same for both outputs:
-print(morris.sort_parameters("y1"))
-print(morris.sort_parameters("y2"))
+# We can also sort the input parameters by decreasing order of influence:
+print(sensitivity_analysis.sort_parameters("y"))
 
 #######################################################################################
 # Lastly,
 # we can use the method :meth:`.MorrisAnalysis.plot`
 # to visualize the different series of indices:
-morris.plot("y1", save=False, show=False, lower_mu=0, lower_sigma=0)
-morris.plot("y2", save=False, show=False, lower_mu=0, lower_sigma=0)
-# Workaround for HTML rendering, instead of ``show=True``
-plt.show()
+sensitivity_analysis.plot("y", save=False, show=True, lower_mu=0, lower_sigma=0)
