@@ -114,7 +114,7 @@ def update_options_from_rest_docstring(
     """
     for option_name, option in options.items():
         try:
-            tmp = re.split(r":type ([\*\w]+): (.*?)", option["description"])
+            tmp = re.split(r":type ([*\w]+): (.*?)", option["description"])
         except KeyError:
             print(
                 "ERROR: failed to detect description for {} of algorithm {}".format(
@@ -154,6 +154,7 @@ class AlgoOptionsDoc:
         long_algo_type: str,
         algo_factory: Any | Factory,
         template: str | None = None,
+        user_guide_anchor: str = "",
     ) -> None:
         """
         Args:
@@ -165,6 +166,8 @@ class AlgoOptionsDoc:
             template: The name of the template file located in the same directory
                 as the current file.
                 If None, :attr:`AlgoOptionsDoc.TEMPLATE` will be used.
+            user_guide_anchor: The anchor of the section of the user guide
+                about these algorithms.
         """
         if template is None:
             self.template = self.TEMPLATE
@@ -194,6 +197,7 @@ class AlgoOptionsDoc:
         self.get_website = None
         self.get_description = None
         self.get_features = None
+        self.user_guide_anchor = user_guide_anchor
 
     def get_module(self, algo_name: str) -> str:
         """Return the module path of an algorithm.
@@ -285,6 +289,7 @@ class AlgoOptionsDoc:
             descriptions=self.descriptions,
             features=self.features,
             libraries=self.libraries,
+            user_guide_anchor=self.user_guide_anchor,
         )
         output_file_path = Path(GEN_OPTS_PATH).parent / output_file_name
         with open(output_file_path, "w", encoding="utf-8") as outf:
@@ -324,24 +329,49 @@ class DriverOptionsDoc(AlgoOptionsDoc):
         long_algo_type: str,
         algo_factory: Any | Factory,
         template: str | None = None,
+        user_guide_anchor: str = "",
     ) -> None:
-
         super().__init__(
             algo_type,
             long_algo_type,
             algo_factory,
             template=template,
+            user_guide_anchor=user_guide_anchor,
         )
         self.algos_names = algo_factory.algorithms
         self.get_description = self.__default_description_getter(algo_factory)
         self.get_website = self.__default_website_getter(algo_factory)
         self.get_class = self.__default_class_getter(algo_factory)
-        self.get_options_schema = lambda algo: self.get_options_schema_from_method(
-            self.get_class(algo)._get_options
-        )
+        self.get_options_schema = self.__default_options_schema_getter(algo_factory)
         if algo_type == "opt":
             self.get_features = get_algorithm_features
 
+    def __default_options_schema_getter(
+        self,
+        algo_factory: DriverFactory,
+    ) -> Callable[[str], dict[dict[str, str]]]:
+        """Return the default algorithm description getter from a driver factory."""
+
+        def get_options_schema(algo: str) -> dict[dict[str, str]]:
+            """Return the options schema.
+
+            Args:
+                algo: The name of the algorithm.
+
+            Returns:
+                The options schema.
+            """
+            options_schema = self.get_options_schema_from_method(
+                self.get_class(algo)._get_options
+            )
+            algo_lib = algo_factory.create(algo)
+            options_grammar = algo_lib.init_options_grammar(algo)
+            return {
+                k: v for k, v in options_schema.items() if k in options_grammar.names
+            }
+
+        return get_options_schema
+
     @staticmethod
     def __default_description_getter(
         algo_factory: DriverFactory,
@@ -403,8 +433,7 @@ class DriverOptionsDoc(AlgoOptionsDoc):
 
 
 class OptPostProcessorAlgoOptionsDoc(AlgoOptionsDoc):
-    """Generator of the reST documentation of a post-processor from a Jinja2
-    template."""
+    """Generator of the reST documentation of a post-processor from a Jinja2 template."""
 
     def __init__(
         self,
@@ -412,12 +441,14 @@ class OptPostProcessorAlgoOptionsDoc(AlgoOptionsDoc):
         long_algo_type: str,
         algo_factory: Any | Factory,
         template: str | None = None,
+        user_guide_anchor: str = "",
     ) -> None:
         super().__init__(
             algo_type,
             long_algo_type,
             algo_factory,
             template=template,
+            user_guide_anchor=user_guide_anchor,
         )
 
         def get_options_schema(algo):
@@ -439,12 +470,14 @@ class InitOptionsDoc(AlgoOptionsDoc):
         long_algo_type: str,
         algo_factory: Any | Factory,
         template: str | None = None,
+        user_guide_anchor: str = "",
     ) -> None:
         super().__init__(
             algo_type,
             long_algo_type,
             algo_factory,
             template=template,
+            user_guide_anchor=user_guide_anchor,
         )
         self.get_options_schema = lambda algo: self.get_options_schema_from_method(
             self.get_class(algo).__init__
@@ -464,7 +497,7 @@ def main(gen_opts_path: str | Path) -> None:
         InitOptionsDoc("mda", "MDA", MDAFactory()),
         InitOptionsDoc("formulation", "MDO Formulation", MDOFormulationsFactory()),
         OptPostProcessorAlgoOptionsDoc("post", "Post-processing", PostFactory()),
-        DriverOptionsDoc("doe", "DOE", DOEFactory()),
+        DriverOptionsDoc("doe", "DOE", DOEFactory(), user_guide_anchor="doe"),
         DriverOptionsDoc("opt", "Optimization", OptimizersFactory()),
         DriverOptionsDoc("linear_solver", "Linear solver", LinearSolversFactory()),
         InitOptionsDoc(
