@@ -77,14 +77,14 @@ sphinx_gallery_conf = {
     "default_thumb_file": str(current_dir / "_static/icon.png"),
     "within_subsection_order": ExampleTitleSortKey,
     "filename_pattern": r"\.py$",
-    "ignore_pattern": r"run\.py",
+    "ignore_pattern": r"(run|post_process_|save_from_)\w*\.py$",
     "only_warn_on_example_error": True,
     "nested_sections": False,
     # directory where function/class granular galleries are stored
     "backreferences_dir": "gen_modules/backreferences",
     # Modules for which function/class level galleries are created. In
     # this case sphinx_gallery and numpy in a tuple of strings.
-    "doc_module": ("gemseo"),
+    "doc_module": "gemseo",
     # objects to exclude from implicit backreferences. The default option
     # is an empty set, i.e. exclude nothing.
     "exclude_implicit_doc": {r"gemseo\.api\.configure_logger"},
@@ -119,6 +119,7 @@ autodoc_mock_imports = [
     "jnius_config",
     "jep",
     "scilab2py",
+    "pyfmi",
 ]
 
 ################################################################################
@@ -289,6 +290,8 @@ html_context["plugins"] = {
     "gemseo-pymoo": "Pymoo wrapper for optimization algorithms",
     "gemseo-scilab": "Interfacing Scilab functions",
     "gemseo-umdo": "Capability for MDO under uncertainty",
+    "gemseo-fmu": "GEMSEO plugin for FMU dynamic models",
+    "gemseo-mma": "GEMSEO plugin for the MMA (Method of Moving Asymptotes) algorithm.",
 }
 
 ###############################################################################
