@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,12 +12,18 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-import logging
+"""|g| main package."""
+from __future__ import annotations
 
-from ._version import get_versions
+import logging as __logging
 
-SOFTWARE_NAME = "GEMSEO"
-LOGGER = logging.getLogger(SOFTWARE_NAME)
+import pkg_resources as __pkg_resources
 
-__version__ = get_versions()["version"]
-del get_versions
+try:
+    __version__ = __pkg_resources.get_distribution("package-name").version
+except __pkg_resources.DistributionNotFound:
+    # package is not installed
+    pass
+
+# by default no logging is produced
+__logging.getLogger(__name__).addHandler(__logging.NullHandler())
