@@ -27,6 +27,7 @@ from numpy import array
 from numpy import atleast_2d
 from numpy import exp as np_exp
 from numpy import full
+from numpy import heaviside
 from numpy import max as np_max
 from numpy import multiply
 from numpy import ndarray
@@ -34,13 +35,17 @@ from numpy import sum as np_sum
 from numpy import zeros
 
 
+# TODO: API: rename to compute_ks_agg
 def ks_agg(
     orig_val: ndarray,
     indices: Sequence[int] | None = None,
     rho: float = 1e2,
     scale: float | ndarray = 1.0,
 ) -> float:
-    """Transform a vector of equalities into a Kreisselmeier–Steinhauser function.
+    """Transform a vector of constraint functions into a KS function.
+
+    The Kreisselmeier–Steinhauser function tends to the maximum operator
+        when the aggregation parameter tends to infinity.
 
     Kreisselmeier G, Steinhauser R (1983)
     Application of Vector Performance Optimization
@@ -62,11 +67,11 @@ def ks_agg(
         orig_val: The original constraint values.
         indices: The indices to generate a subset of the outputs to aggregate.
             If ``None``, aggregate all the outputs.
-        rho: The multiplicative parameter in the exponential.
+        rho: The aggregation parameter.
         scale: The scaling factor for multiplying the constraints.
 
     Returns:
-        The aggregated function value.
+        The KS function value.
     """
     if indices is not None:
         orig_val = orig_val[indices]
@@ -82,6 +87,7 @@ def ks_agg(
     )
 
 
+# TODO: API: rename to compute_total_ks_agg_jac
 def ks_agg_jac_v(
     orig_val: ndarray,
     orig_jac: ndarray,
@@ -89,10 +95,7 @@ def ks_agg_jac_v(
     rho: float = 1e2,
     scale: float | ndarray = 1.0,
 ) -> ndarray:
-    """Aggregate inequality constraints.
-
-    Jacobian vector product of the constraints aggregation method for inequality
-    constraints.
+    """Compute the Jacobian of KS function with respect to constraint function inputs.
 
     See :cite:`kennedy2015improved` and  :cite:`kreisselmeier1983application`.
 
@@ -105,7 +108,7 @@ def ks_agg_jac_v(
         scale: The scaling factor for multiplying the constraints.
 
     Returns:
-        The aggregated function Jacobian vector product.
+        The Jacobian of KS function with respect to constraint function inputs.
     """
     if indices is not None:
         orig_jac = orig_jac[indices, :]
@@ -120,15 +123,14 @@ def ks_agg_jac_v(
     return np_sum(multiply(atleast_2d(weights).T, orig_jac), axis=0)
 
 
+# TODO: API: rename to compute_partial_ks_agg_jac
 def ks_agg_jac(
     orig_val: ndarray,
     indices: Sequence[int] | None = None,
     rho: float = 1e2,
     scale: float | ndarray = 1.0,
 ) -> ndarray:
-    """Transform a vector of equalities into a scalar equivalent constraint.
-
-    Jacobian of the Constraints aggregation method for inequality constraints.
+    """Compute the Jacobian of KS function with respect to constraint functions.
 
     See :cite:`kennedy2015improved` and  :cite:`kreisselmeier1983application`.
 
@@ -140,7 +142,7 @@ def ks_agg_jac(
         scale: The scaling factor for multiplying the constraints.
 
     Returns:
-        The aggregated function Jacobian.
+        The Jacobian of KS function with respect to constraint functions.
     """
     full_size = orig_val.size
     if indices is not None:
@@ -155,13 +157,17 @@ def ks_agg_jac(
     return __filter_jac(der, full_size, indices)
 
 
+# TODO: API: rename to compute_iks_agg
 def iks_agg(
     orig_val: ndarray,
     indices: Sequence[int] | None = None,
     rho: float = 1e2,
     scale: float | ndarray = 1.0,
 ) -> float:
-    """Aggregate IKS Constraints for inequality constraints.
+    """Transform a vector of constraint functions into an induces exponential function.
+
+    The induces exponential function (IKS) tends to the maximum operator when
+        the aggregation parameter tends to infinity.
 
     See :cite:`kennedy2015improved`.
 
@@ -173,7 +179,7 @@ def iks_agg(
         scale: The scaling factor for multiplying the constraints.
 
     Returns:
-        The aggregated value.
+        The IKS function value.
     """
     if indices is not None:
         orig_val = orig_val[indices]
@@ -187,6 +193,7 @@ def iks_agg(
     return iks
 
 
+# TODO: API: rename to compute_total_iks_agg_jac
 def iks_agg_jac_v(
     orig_val: ndarray,
     orig_jac: ndarray,
@@ -194,10 +201,7 @@ def iks_agg_jac_v(
     rho: float = 1e2,
     scale: float | ndarray = 1.0,
 ) -> ndarray:
-    """Aggregate inequality constraints.
-
-    Jacobian vector product of the IKS Constraints aggregation method for inequality
-    constraints.
+    """Compute the Jacobian of IKS function with respect to constraints inputs.
 
     See :cite:`kennedy2015improved`.
 
@@ -210,7 +214,7 @@ def iks_agg_jac_v(
         scale: The scaling factor for multiplying the constraints.
 
     Returns:
-        The aggregated function Jacobian vector product.
+        The Jacobian of IKS function with respect to constraints inputs.
     """
     if indices is not None:
         orig_jac = orig_jac[indices, :]
@@ -241,13 +245,14 @@ def iks_agg_jac_v(
     return (-iks_den_der / iks_den**2) * iks_num + iks_num_der / iks_den
 
 
+# TODO: API: rename to compute_partial_iks_agg_jac
 def iks_agg_jac(
     orig_val: ndarray,
     indices: Sequence[int] | None = None,
     rho: float = 1e2,
     scale: float | ndarray = 1.0,
 ) -> ndarray:
-    """Jacobian of the IKS Constraints aggregation method for inequality constraints.
+    """Compute the Jacobian of IKS function with respect to constraints functions.
 
     Kennedy, Graeme J., and Jason E. Hicken.
     "Improved constraint-aggregation methods."
@@ -262,7 +267,7 @@ def iks_agg_jac(
         scale: The scaling factor for multiplying the constraints.
 
     Returns:
-        The aggregated function Jacobian.
+        The Jacobian of IKS function with respect to constraints functions.
     """
     full_size = orig_val.size
     if indices is not None:
@@ -308,12 +313,146 @@ def __filter_jac(
     return orig_jac
 
 
+# TODO: API: rename to compute_sum_square_agg
 def sum_square_agg(
     orig_val: ndarray,
     indices: Sequence[int] | None = None,
     scale: float | ndarray = 1.0,
 ) -> ndarray:
-    """Transform a vector of equalities into a sum of squared constraints.
+    """Transform a vector of constraint functions into a sum squared function.
+
+    The sum squared function is the sum of the squares of the input vector components.
+
+    Args:
+        orig_val: The input vector.
+        indices: The indices to generate a subset of the outputs to aggregate.
+            If ``None``, scale all the constraint values.
+        scale: The scaling factor for multiplying the constraints.
+
+    Returns:
+        The sum squared function value.
+    """
+    if indices is not None:
+        orig_val = orig_val[indices]
+    return np_sum(scale * orig_val**2)
+
+
+# TODO: API: rename to compute_total_sum_square_agg_jac
+def sum_square_agg_jac_v(
+    orig_val: ndarray,
+    orig_jac: ndarray,
+    indices: Sequence[int] | None = None,
+    scale: float | ndarray = 1.0,
+) -> ndarray:
+    """Compute the Jacobian of squared sum function with respect to constraints inputs.
+
+    Args:
+        orig_val: The original constraint values.
+        orig_jac: The original constraint jacobian.
+        indices: The indices to generate a subset of the outputs to aggregate.
+            If ``None``, aggregate all the outputs.
+        scale: The scaling factor for multiplying the constraints.
+
+    Returns:
+        The Jacobian of squared sum function with respect to constraints inputs.
+    """
+    orig_jac = atleast_2d(orig_jac)
+    if indices is not None:
+        orig_jac = orig_jac[indices, :]
+        orig_val = orig_val[indices]
+
+    return np_sum((2 * scale * orig_val).flatten() * orig_jac.T, axis=1)
+
+
+# TODO: API: rename to compute_partial_sum_square_agg_jac
+def sum_square_agg_jac(
+    orig_val: ndarray,
+    indices: Sequence[int] | None = None,
+    scale: float | ndarray = 1.0,
+) -> ndarray:
+    """Compute the Jacobian of squared sum function with respect to constraints.
+
+    Args:
+        orig_val: The original constraint values.
+        indices: The indices to generate a subset of the outputs to aggregate.
+            If ``None``, aggregate all the outputs.
+        scale: The scaling factor for multiplying the constraints.
+
+    Returns:
+        The Jacobian of squared sum function with respect to constraints.
+    """
+    if indices is not None:
+        jac = zeros((1, orig_val.size))
+        jac[:, indices] = 2.0 * scale * orig_val[indices]
+    else:
+        jac = full((1, orig_val.size), 2.0) * atleast_2d(scale * orig_val)
+
+    return jac
+
+
+# TODO: API: rename to compute_max_agg
+def max_agg(
+    orig_val: ndarray,
+    indices: Sequence[int] | None = None,
+    scale: float | ndarray = 1.0,
+) -> float:
+    """Transform a vector of constraints into a max of all values.
+
+    The maximum function is not differentiable for all input values.
+
+    Args:
+        orig_val: The original constraint values.
+        indices: The indices to generate a subset of the outputs to aggregate.
+            If ``None``, aggregate all the outputs.
+        scale: The scaling factor for multiplying the constraints.
+
+    Returns:
+        The maximum value.
+    """
+    if indices is not None:
+        orig_val = orig_val[indices]
+    orig_val *= scale
+    return array([np_max(orig_val)])
+
+
+# TODO: API: rename to compute_max_agg_jac
+def max_agg_jac_v(
+    orig_val: ndarray,
+    orig_jac: ndarray,
+    indices: Sequence[int] | None = None,
+    scale: float | ndarray = 1.0,
+) -> ndarray:
+    """Compute the Jacobian of max function with respect to constraints inputs.
+
+    Args:
+        orig_val: The original constraint values.
+        orig_jac: The original constraint jacobian.
+        indices: The indices to generate a subset of the outputs to aggregate.
+            If ``None``, aggregate all the outputs.
+        scale: The scaling factor for multiplying the constraints.
+
+    Returns:
+        The Jacobian of max function with respect to constraints inputs.
+    """
+    if indices is not None:
+        orig_jac = orig_jac[indices, :]
+        orig_val = orig_val[indices]
+    orig_jac *= scale
+    orig_val *= scale
+    i_max = np_argmax(orig_val)
+
+    return atleast_2d(orig_jac)[i_max, :]
+
+
+def compute_sum_positive_square_agg(
+    orig_val: ndarray,
+    indices: Sequence[int] | None = None,
+    scale: float | ndarray = 1.0,
+) -> ndarray:
+    """Transform a vector of constraint functions into a positive sum squared function.
+
+    The positive sum squared function is the sum of the squares of the input vector
+        components that are positive.
 
     Args:
         orig_val: The original constraint values.
@@ -322,24 +461,20 @@ def sum_square_agg(
         scale: The scaling factor for multiplying the constraints.
 
     Returns:
-        The aggregated function.
+        The positive sum squared function value.
     """
     if indices is not None:
         orig_val = orig_val[indices]
-    orig_val *= scale
-    return np_sum(orig_val**2)
+    return np_sum(scale * (orig_val**2) * heaviside(orig_val, 0))
 
 
-def sum_square_agg_jac_v(
+def compute_total_sum_square_positive_agg_jac(
     orig_val: ndarray,
     orig_jac: ndarray,
     indices: Sequence[int] | None = None,
     scale: float | ndarray = 1.0,
 ) -> ndarray:
-    """Transform a vector of equalities into a sum of squared constraints.
-
-    Jacobian vector product of the constraints aggregation method for equality
-    constraints.
+    """Compute the Jacobian of positive sum squared function w.r.t. constraints inputs.
 
     Args:
         orig_val: The original constraint values.
@@ -349,24 +484,24 @@ def sum_square_agg_jac_v(
         scale: The scaling factor for multiplying the constraints.
 
     Returns:
-        The aggregated function Jacobian vector product.
+        The Jacobian of positive sum squared function w.r.t. constraints inputs.
     """
+    orig_jac = atleast_2d(orig_jac)
     if indices is not None:
         orig_jac = orig_jac[indices, :]
         orig_val = orig_val[indices]
-    orig_jac *= scale
-    orig_val *= scale
-    return 2 * np_sum(orig_jac * orig_val, axis=0)
+    return np_sum(
+        (2 * scale * orig_val * heaviside(orig_val, 0)).flatten() * orig_jac.T,
+        axis=1,
+    )
 
 
-def sum_square_agg_jac(
+def compute_partial_sum_positive_square_agg_jac(
     orig_val: ndarray,
     indices: Sequence[int] | None = None,
     scale: float | ndarray = 1.0,
 ) -> ndarray:
-    """Transform a vector of equalities into a sum of squared constraints.
-
-    Jacobian of the constraints aggregation method for equality constraints.
+    """Compute the Jacobian of positive sum squared function w.r.t. constraints.
 
     Args:
         orig_val: The original constraint values.
@@ -375,66 +510,14 @@ def sum_square_agg_jac(
         scale: The scaling factor for multiplying the constraints.
 
     Returns:
-        The aggregated function Jacobian.
+        The Jacobian of positive sum squared function w.r.t. constraints.
     """
     if indices is not None:
         jac = zeros((1, orig_val.size))
-        jac[:, indices] = 2.0
+        jac[:, indices] = (
+            2.0 * scale * orig_val[indices] * heaviside(orig_val[indices], 0.0)
+        )
     else:
-        jac = full((1, orig_val.size), 2.0)
+        jac = atleast_2d(2 * scale * orig_val * heaviside(orig_val, 0.0))
 
     return jac
-
-
-def max_agg(
-    orig_val: ndarray,
-    indices: Sequence[int] | None = None,
-    scale: float | ndarray = 1.0,
-) -> float:
-    """Transform a vector of equalities into a max of all values.
-
-    Constraints aggregation method for inequality constraints.
-
-    Args:
-        orig_val: The original constraint values.
-        indices: The indices to generate a subset of the outputs to aggregate.
-            If ``None``, aggregate all the outputs.
-        scale: The scaling factor for multiplying the constraints.
-
-    Returns:
-        The aggregated function.
-    """
-    if indices is not None:
-        orig_val = orig_val[indices]
-    orig_val *= scale
-    return array([np_max(orig_val)])
-
-
-def max_agg_jac_v(
-    orig_val: ndarray,
-    orig_jac: ndarray,
-    indices: Sequence[int] | None = None,
-    scale: float | ndarray = 1.0,
-) -> ndarray:
-    """Transform a vector of equalities into the max of all the values.
-
-    Jacobian vector product of the max constraints aggregation method for inequality
-    constraints.
-
-    Args:
-        orig_val: The original constraint values.
-        orig_jac: The original constraint jacobian.
-        indices: The indices to generate a subset of the outputs to aggregate.
-            If ``None``, aggregate all the outputs.
-        scale: The scaling factor for multiplying the constraints.
-
-    Returns:
-        The aggregated function.
-    """
-    if indices is not None:
-        orig_jac = orig_jac[indices, :]
-        orig_val = orig_val[indices]
-    orig_jac *= scale
-    orig_val *= scale
-    i_max = np_argmax(orig_val)
-    return atleast_2d(orig_jac)[i_max, :]
