@@ -27,6 +27,7 @@ import sys
 from ast import literal_eval
 from itertools import chain
 from itertools import islice
+from numbers import Number
 from pathlib import Path
 from typing import Any
 from typing import Callable
@@ -43,13 +44,15 @@ from xml.etree.ElementTree import parse as parse_element
 import h5py
 from numpy import array
 from numpy import array_equal
+from numpy import atleast_1d
 from numpy import atleast_2d
-from numpy import concatenate
 from numpy import float64
+from numpy import hstack
 from numpy import ndarray
 from numpy import string_
 from numpy import uint8
 from numpy.linalg import norm
+from numpy.typing import NDArray
 from xxhash._xxhash import xxh3_64_hexdigest
 
 from gemseo.utils.ggobi_export import save_data_arrays_to_xml
@@ -65,22 +68,42 @@ ReturnedHdfMissingOutputType = Tuple[
 
 
 class Database:
-    """Class to store evaluations of functions, such as DOE or optimization histories.
+    """Storage of :class:`.MDOFunction` evaluations.
 
-    Avoid multiple calls of the same functions,
-    useful when simulations are costly.
+    A :class:`.Database` is typically attached to an :class:`.OptimizationProblem`
+    to store the evaluations of its objective, constraints and observables.
 
-    It is also used to store inputs and retrieve them
-    for optimization graphical post-processing and plots
-    generation.
+    Then,
+    a :class:`.Database` can be an optimization history
+    or a collection of samples in the case of a DOE.
 
-    Can be serialized to HDF5 for portability and cold post-processing.
+    It is useful when simulations are costly
+    because it avoids re-evaluating functions
+    at points where they have already been evaluated
+
+    .. seealso:: :class:`.NormDBFunction`
+
+    It can also be post-processed by an :class:`.OptPostProcessor`
+    to visualize its content,
+    e.g. :class:`.OptHistoryView` generating a series of graphs
+    to visualize the histories of the objective, constraints and design variables.
+
+    A :class:`.Database` can be serialized to HDF5
+    for portability and cold post-processing.
+
+    .. note::
+        Serializing an :class:`.OptimizationProblem`
+        using its method :class:`~.OptimizationProblem.export_hdf`
+        also serializes its :class:`.Database`.
 
     The database is based on a two-levels dictionary-like mapping such as
     ``{key_level_1: {key_level_2: value_level_2}}`` with:
 
         * ``key_level_1``: the values of the input design variables that have been used
-          during the evaluations;
+          during the evaluations,
+          if the types of the design variables are different,
+          then they are promoted to the unique type that can represent all them,
+          for instance integer would be promoted to float;
         * ``key_level_2``: the name of the output functions that have been returned,
           the name of the gradient
           (the gradient of a function called ``func`` is typically denoted as ``@func``),
@@ -103,6 +126,9 @@ class Database:
     GRAD_TAG = "@"
     ITER_TAG = "Iter"
 
+    __component_names_to_names: dict[str, str]
+    """The variable names associated with variable component names."""
+
     def __init__(
         self,
         input_hdf_file: str | Path | None = None,
@@ -115,7 +141,7 @@ class Database:
                 It should have been generated with :meth:`.Database.export_hdf`.
             name: The name to be given to the database.
                 If ``None``, use the class name.
-        """
+        """  # noqa: D205, D212, D415
         if name is None:
             self.name = self.__class__.__name__
         else:
@@ -134,6 +160,8 @@ class Database:
         if input_hdf_file is not None:
             self.import_hdf(input_hdf_file)
 
+        self.__component_names_to_names = {}
+
     @property
     def last_item(self) -> DatabaseValueType:
         """The last item stored in the database."""
@@ -185,8 +213,8 @@ class Database:
         n_cval = len(curr_val)
         return (n_cval == 1 and self.ITER_TAG in curr_val) or n_cval == 0
 
+    @staticmethod
     def get_hashed_key(
-        self,
         x_vect: ndarray | HashableNdarray,
         copy: bool = False,
     ) -> HashableNdarray:
@@ -367,7 +395,7 @@ class Database:
         if nkeys == 0:
             raise ValueError("The database is empty.")
         if iteration < 0:
-            iteration = nkeys + iteration
+            iteration += nkeys
         if iteration >= nkeys or (iteration < 0 and -iteration > nkeys):
             raise ValueError(
                 "Iteration required should be lower "
@@ -494,7 +522,7 @@ class Database:
         Returns:
             True if the history of the gradient is empty, False otherwise.
         """
-        return len(self.get_func_grad_history(funcname, x_hist=False)) == 0
+        return len(self.get_func_grad_history(funcname)) == 0
 
     def contains_x(self, x_vect: ndarray) -> bool:
         """Check if the history contains a specific value of input design variables.
@@ -637,10 +665,7 @@ class Database:
             if cval_ok and values_not_empty:
                 self.notify_newiter_listeners(x_vect)
 
-    def add_store_listener(
-        self,
-        listener_func: Callable,
-    ) -> None:
+    def add_store_listener(self, listener_func: Callable) -> None:
         """Add a listener to be called when an item is stored to the database.
 
         Args:
@@ -783,8 +808,9 @@ class Database:
         all_iterations: bool = False,
         stacked_data: Iterable[str] | None = None,
     ) -> tuple[list[list[float | ndarray]], list[ndarray]]:
-        """Return the complete history of the optimization: design variables, functions
-        and gradients.
+        """Return the complete history of the optimization.
+
+        This includes the design variables, functions and gradients.
 
         Args:
             functions: The names of output functions.
@@ -800,8 +826,8 @@ class Database:
                 trust region radii).
 
         Returns:
-            The history of the output values.
-            The history of the input values.
+            The history of the output values,
+            then the history of the input values.
         """
         functions, stacked_data = self._format_history_names(functions, stacked_data)
         f_history = []
@@ -851,8 +877,8 @@ class Database:
         """
         return array(array(data, copy=False).real, dtype=float64)
 
+    @staticmethod
     def _add_hdf_input_dataset(
-        self,
         index_dataset: int,
         design_vars_group: h5py.Group,
         design_vars_values: HashableNdarray,
@@ -920,8 +946,8 @@ class Database:
         if values:
             self._add_hdf_scalar_output(index_dataset, values_group, values)
 
+    @staticmethod
     def _get_missing_hdf_output_dataset(
-        self,
         index_dataset: int,
         keys_group: h5py.Group,
         output_values: Mapping[str, float | ndarray | list[int]],
@@ -964,8 +990,8 @@ class Database:
 
         return missing_names_values, missing_names_idx_mapping
 
+    @staticmethod
     def _add_hdf_name_output(
-        self,
         index_dataset: int,
         keys_group: h5py.Group,
         keys: list[str],
@@ -1030,20 +1056,20 @@ class Database:
     ) -> None:
         """Add a new vector of values to the hdf5 group of output values.
 
-        Create a sub-group dedicated to vectors in the group of output
+        Create a subgroup dedicated to vectors in the group of output
         values.
-        Inside this sub-group, a new dataset is created for each vector.
-        If the sub-group already exists, it is just appended.
+        Inside this subgroup, a new dataset is created for each vector.
+        If the subgroup already exists, it is just appended.
         Otherwise, the sub-group is created.
 
         Args:
             index_dataset: The index of the hdf5 entry.
-            idx_sub_group: The index of the dataset in the sub-group of vectors.
+            idx_sub_group: The index of the dataset in the subgroup of vectors.
             values_group: The hdf5 group of the output values.
             value: The vector which is added to the group.
 
         Raises:
-            ValueError: If the index of the dataset in the sub-group of vectors
+            ValueError: If the index of the dataset in the subgroup of vectors
                 already exist.
         """
         sub_group_name = f"arr_{index_dataset}"
@@ -1105,7 +1131,7 @@ class Database:
     ):
         """Create the new hdf5 datasets for the given inputs and outputs.
 
-        Useful when exporting the database to an hdf5 file.
+        Useful when exporting the database to a hdf5 file.
 
         Args:
             index_dataset: The index of the new hdf5 entry.
@@ -1185,7 +1211,7 @@ class Database:
         Args:
             filename: The path of the HDF file.
         """
-        with h5py.File(filename, "r") as h5file:
+        with h5py.File(filename) as h5file:
             design_vars_grp = h5file["x"]
             keys_group = h5file["k"]
             values_group = h5file["v"]
@@ -1263,6 +1289,35 @@ class Database:
             )
         return design_variables_names
 
+    def __set_variable_component_name(
+        self, name: str, component: int, size: int
+    ) -> str:
+        """Define the name of the component of a variable.
+
+        Args:
+            name: The name of the variable.
+            component: The component of the variable.
+            size: The size of the variable.
+
+        Returns:
+            The name of the component of a variable.
+        """
+        component_name = name if size == 1 else f"{name} ({component})"
+        self.__component_names_to_names[component_name] = name
+        return component_name
+
+    def retrieve_variable_name(self, name: str) -> str:
+        """Retrieve a variable name from a name.
+
+        Args:
+            name: A name.
+
+        Returns:
+            The name of the variable for which ``name`` is the name of a component,
+            or ``name`` otherwise.
+        """
+        return self.__component_names_to_names.get(name, name)
+
     def get_history_array(
         self,
         functions: Iterable[str] | None = None,
@@ -1272,87 +1327,88 @@ class Database:
         add_dv: bool = True,
         all_iterations: bool = False,
         stacked_data: Iterable[str] | None = None,
-    ) -> tuple[ndarray, list[str], Iterable[str]]:
-        """Return the history of the optimization process.
+    ) -> tuple[NDArray[Number | str], list[str], Iterable[str]]:
+        """Return the database as a 2D array shaped as ``(n_iterations, n_features)``.
+
+        The features are the outputs of interest and possibly the design variables.
 
         Args:
-            functions: The names of output functions that must be returned.
-            design_variables_names: The names of the input design variables.
-            add_missing_tag: If True, add the tag specified in ``missing_tag`` for
-                data that are not available.
+            functions: The names of the outputs that must be returned.
+            design_variables_names: The names of the design variables.
+            add_missing_tag: If ``True``,
+                add the tag specified in ``missing_tag``
+                for data that are not available.
             missing_tag: The tag that is added for data that are not available.
-            add_dv: If True, the input design variables are returned in the history.
-            all_iterations: If True, the points which are called at several
-                iterations will be duplicated in the history (each duplicate
-                corresponding to a different calling index); otherwise each point
-                will appear only once (with the latest calling index).
-            stacked_data: The names of outputs corresponding to data stored as
-                ``iterable`` (e.g. iterations, penalization parameters or
-                trust region radii).
+            add_dv: If ``True``,
+                the input design variables are returned in the history.
+            all_iterations: If ``True``,
+                the points which are called at several iterations will be duplicated
+                in the history
+                (each duplicate corresponding to a different calling index);
+                otherwise each point will appear only once
+                (with the latest calling index).
+            stacked_data: The names of outputs
+                corresponding to data stored as ``Iterable``
+                (e.g. iterations, penalization parameters or trust region radii).
 
         Returns:
-            The values of the history.
-            The names of the columns corresponding to the values of the history.
-            The names of the output functions.
+            The history as an 2D array
+            whose rows are observations and columns are the variables,
+            the names of these columns
+            and the names of the output functions.
         """
-        if functions is None:
-            functions = self.get_all_data_names()
+        f_names = functions
+        if f_names is None:
+            f_names = self.get_all_data_names()
+
         f_history, x_history = self.get_complete_history(
-            functions, add_missing_tag, missing_tag, all_iterations, stacked_data
+            f_names, add_missing_tag, missing_tag, all_iterations, stacked_data
         )
-        design_variables_names = self._format_design_variables_names(
-            design_variables_names, len(x_history[0])
-        )
-        flat_vals = []
-        fdict = {}
-        for f_val_i in f_history:
-            flat_vals_i = []
-            for f_val, f_name in zip(f_val_i, functions):
-                if isinstance(f_val, list):
-                    f_val = array(f_val)
-                if isinstance(f_val, ndarray) and len(f_val) > 1:
-                    flat_vals_i = flat_vals_i + f_val.tolist()
-                    fdict[f_name] = [f"{f_name} ({i})" for i in range(len(f_val))]
-                else:
-                    flat_vals_i.append(f_val)
-                    if f_name not in fdict:
-                        fdict[f_name] = [f_name]
-            flat_vals.append(flat_vals_i)
-        flat_names = list(chain(*fdict.values()))
-
-        x_flat_vals = []
-        xdict = {}
-        for x_val_i in x_history:
-            x_flat_vals_i = []
-            for x_val, x_name in zip(x_val_i, design_variables_names):
-                if isinstance(x_val, ndarray) and len(x_val) > 1:
-                    x_flat_vals_i = x_flat_vals_i + x_val.tolist()
-                    xdict[x_name] = [f"{x_name} ({i})" for i in range(len(x_val))]
-                else:
-                    x_flat_vals_i.append(x_val)
-                    if x_name not in xdict:
-                        xdict[x_name] = [x_name]
-            x_flat_vals.append(x_flat_vals_i)
-
-        x_flat_names = list(chain(*xdict.values()))
+        f_flat_names, f_flat_values = self.__split_history(f_history, f_names)
+        variables_flat_names = f_flat_names
+        f_history = array(f_flat_values).real
         if add_dv:
-            variables_names = flat_names + x_flat_names
+            x_names = self._format_design_variables_names(
+                design_variables_names, len(x_history[0])
+            )
+            x_flat_names, x_flat_values = self.__split_history(x_history, x_names)
+            variables_flat_names = f_flat_names + x_flat_names
+            x_history = array(x_flat_values).real
+            variables_history = hstack((f_history, x_history))
         else:
-            variables_names = flat_names
+            variables_history = f_history
 
-        f_history = array(flat_vals).real
-        x_history = array(x_flat_vals).real
-        if add_dv:
-            f2d = atleast_2d(f_history)
-            x2d = atleast_2d(x_history)
-            if f2d.shape[0] == 1:
-                f2d = f2d.T
-            if x2d.shape[0] == 1:
-                x2d = x2d.T
-            values_array = concatenate((f2d, x2d), axis=1)
-        else:
-            values_array = f_history
-        return values_array, variables_names, functions
+        return atleast_2d(variables_history), variables_flat_names, f_names
+
+    def __split_history(
+        self, history: list[list[float | ndarray]] | list[ndarray], names: Iterable[str]
+    ) -> tuple[list[str], list[float]]:
+        """Split a history.
+
+        Args:
+            history: A history of values.
+            names: The names of the variables.
+
+        Returns:
+            The history as an array whose lines are observations,
+            the names of the columns of the array.
+        """
+        flat_values = []
+        names_to_flat_names = {}
+        for values in history:
+            flat_value = []
+            for value, name in zip(values, names):
+                value = atleast_1d(value)
+                size = value.size
+                flat_value.extend(value)
+                names_to_flat_names[name] = [
+                    self.__set_variable_component_name(name, i, size)
+                    for i in range(size)
+                ]
+
+            flat_values.append(flat_value)
+
+        return list(chain(*names_to_flat_names.values())), flat_values
 
     def export_to_ggobi(
         self,
@@ -1368,7 +1424,7 @@ class Database:
             design_variables_names: The names of the input design variables.
         """
         values_array, variables_names, functions = self.get_history_array(
-            functions, design_variables_names, add_missing_tag=True, missing_tag="NA"
+            functions, design_variables_names, add_missing_tag=True
         )
         LOGGER.info("Export to ggobi for functions: %s", str(functions))
         LOGGER.info("Export to ggobi file: %s", file_path)
@@ -1445,7 +1501,7 @@ class HashableNdarray:
         Args:
             wrapped: The array that must be wrapped.
             tight: If True, the wrapped array is copied.
-        """
+        """  # noqa: D205, D212, D415
         self.__tight = tight
         self.wrapped = array(wrapped) if tight else wrapped
         self.__hash = int(xxh3_64_hexdigest(wrapped.view(uint8)), 16)
