@@ -139,8 +139,8 @@ class DesignSpace(collections.abc.MutableMapping):
     """The name of the space."""
 
     dimension: int
-    """The total dimension of the space,
-    corresponding to the sum of the sizes of the variables."""
+    """The total dimension of the space, corresponding to the sum of the sizes of the
+    variables."""
 
     # TODO: API: rename all variables_x to variable_x
     variables_names: list[str]
@@ -150,13 +150,12 @@ class DesignSpace(collections.abc.MutableMapping):
     """The sizes of the variables."""
 
     variables_types: dict[str, ndarray]
-    """The types of the variables components,
-    which can be any :attr:`.DesignSpace.DesignVariableType`."""
+    """The types of the variables components, which can be any
+    :attr:`.DesignSpace.DesignVariableType`."""
 
     normalize: dict[str, ndarray]
-    """The normalization policies
-    of the variables components indexed by the variables names;
-    if `True`, the component can be normalized."""
+    """The normalization policies of the variables components indexed by the variables
+    names; if `True`, the component can be normalized."""
 
     __VARIABLE_TYPES_TO_DTYPES: ClassVar[dict[str, str]] = {
         DesignVariableType.FLOAT.value: "float64",
@@ -208,7 +207,7 @@ class DesignSpace(collections.abc.MutableMapping):
                 If None, start with an empty design space.
             name: The name to be given to the design space,
                 `None` if the design space is unnamed.
-        """
+        """  # noqa: D205, D212, D415
         self.name = name
         self.variables_names = []
         self.dimension = 0
@@ -460,7 +459,17 @@ class DesignSpace(collections.abc.MutableMapping):
                 self.__VARIABLE_TYPES_TO_DTYPES[self.variables_types[name][0]],
                 copy=False,
             )
-            self._check_current_value(name)
+            try:
+                self._check_current_value(name)
+            except ValueError:
+                # If a ValueError is raised,
+                # we must remove the variable from the design space.
+                # When using a python script, this has no interest.
+                # When using a notebook, a cell can raise a ValueError,
+                # but we can continue to the next cell,
+                # and use a design space which contains a variables that leads to error.
+                self.remove_variable(name)
+                raise
 
         self.__update_current_metadata()
 
@@ -929,7 +938,8 @@ class DesignSpace(collections.abc.MutableMapping):
                 )
 
             for i in range(size):
-                x_real = x_dict[name][i].real
+                x_real = value[i].real
+
                 if l_b is not None and x_real < l_b[i] - self.__bound_tol:
                     raise ValueError(
                         f"The component {name}[{i}] of the given array ({x_real}) "
@@ -1205,7 +1215,6 @@ class DesignSpace(collections.abc.MutableMapping):
 
     def __update_normalization_vars(self) -> None:
         """Compute the inner attributes used for normalization and unnormalization."""
-
         self.__lower_bounds_array = self.get_lower_bounds()
         self.__upper_bounds_array = self.get_upper_bounds()
         self._norm_factor = self.__upper_bounds_array - self.__lower_bounds_array
