@@ -33,7 +33,9 @@ from typing import MutableMapping
 from typing import Tuple
 from typing import Union
 
-from docstring_inheritance import GoogleDocstringInheritanceMeta
+from numpy import array
+from numpy import dtype
+from numpy import int32
 from numpy import ndarray
 from numpy import savetxt
 
@@ -45,6 +47,7 @@ from gemseo.algos.opt_problem import OptimizationProblem
 from gemseo.algos.opt_result import OptimizationResult
 from gemseo.core.parallel_execution import ParallelExecution
 from gemseo.core.parallel_execution import SUBPROCESS_NAME
+from gemseo.utils.python_compatibility import Final
 
 LOGGER = logging.getLogger(__name__)
 
@@ -62,22 +65,26 @@ class DOEAlgorithmDescription(DriverDescription):
     """The minimum dimension of the parameter space."""
 
 
-class DOELibrary(DriverLib, metaclass=GoogleDocstringInheritanceMeta):
+class DOELibrary(DriverLib):
     """Abstract class to use for DOE library link See DriverLib."""
 
-    unit_samples: ndarray | None
+    unit_samples: ndarray
     """The input samples transformed in :math:`[0,1]`."""
 
-    samples: ndarray | None
-    """The input samples."""
+    samples: ndarray
+    """The input samples with the design space variable types stored as dtype
+    metadata."""
 
     seed: int
-    """The seed to be used for replicability reasons.
+    """The seed to be used for reproducibility reasons.
 
-    It increments with each generation of samples
-    so that repeating the generation of sets of :math:`N` leads to different sets.
+    This seed is initialized at 0 and each call to :meth:`.execute` increments it before
+    using it.
     """
 
+    eval_jac: bool
+    """Whether to evaluate the Jacobian."""
+
     DESIGN_ALGO_NAME = "Design algorithm"
     SAMPLES_TAG = "samples"
     PHIP_CRITERIA = "phi^p"
@@ -92,12 +99,19 @@ class DOELibrary(DriverLib, metaclass=GoogleDocstringInheritanceMeta):
     SEED = "seed"
     _NORMALIZE_DS = False
 
+    # TODO: use DesignSpace enum once there are hashable.
+    __DESIGN_VARIABLE_TYPE_TO_PYTHON_TYPE: Final[dict[str, type]] = {
+        "float": float,
+        "integer": int32,
+    }
+
     def __init__(self):
         """Constructor Abstract class."""
         super().__init__()
-        self.unit_samples = None
-        self.samples = None
+        self.unit_samples = array([])
+        self.samples = array([])
         self.seed = 0
+        self.eval_jac = False
 
     # TODO: API: remove this method
     @staticmethod
@@ -126,7 +140,9 @@ class DOELibrary(DriverLib, metaclass=GoogleDocstringInheritanceMeta):
         options[self.DIMENSION] = self.problem.dimension
         options[self._VARIABLES_NAMES] = self.problem.design_space.variables_names
         options[self._VARIABLES_SIZES] = self.problem.design_space.variables_sizes
+
         self.unit_samples = self._generate_samples(**options)
+
         LOGGER.debug(
             (
                 "The DOE algorithm %s of %s has generated %s samples "
@@ -137,9 +153,8 @@ class DOELibrary(DriverLib, metaclass=GoogleDocstringInheritanceMeta):
             len(self.unit_samples),
             self.unit_samples.shape[1],
         )
-        self.samples = self.problem.design_space.untransform_vect(
-            self.unit_samples, no_check=True
-        )
+
+        self.samples = self.__create_samples()
 
         if options.get(self.N_PROCESSES, 1) > 1:
             # Initialize the order as it is not necessarily guaranteed
@@ -148,7 +163,33 @@ class DOELibrary(DriverLib, metaclass=GoogleDocstringInheritanceMeta):
                 self.problem.database.store(sample, {}, add_iter=True)
 
         self.init_iter_observer(len(self.unit_samples))
-        self.problem.add_callback(self.new_iteration_callback)
+
+    def __create_samples(self) -> ndarray:
+        """Create the samples with the design variable types as dtype metadata.
+
+        Returns:
+            The samples.
+        """
+        samples = self.problem.design_space.untransform_vect(
+            self.unit_samples, no_check=True
+        )
+
+        variable_types = self.problem.design_space.variables_types
+        unique_variable_types = {t[0] for t in variable_types.values()}
+
+        if len(unique_variable_types) > 1:
+            # When the design space have both float and integer variables,
+            # the samples array has the float dtype.
+            # We record the integer variables types to later be able to restore the
+            # proper data type.
+            python_var_types = {
+                name: self.__DESIGN_VARIABLE_TYPE_TO_PYTHON_TYPE[type_[0]]
+                for name, type_ in variable_types.items()
+                if type_[0] != "float"
+            }
+            samples.dtype = dtype(samples.dtype, metadata=python_var_types)
+
+        return samples
 
     def _generate_samples(self, **options: Any) -> ndarray:
         """Generate the samples of the input variables.
@@ -215,7 +256,6 @@ class DOELibrary(DriverLib, metaclass=GoogleDocstringInheritanceMeta):
                 * If neither ``n_samples`` nor ``levels`` is provided.
                 * If both ``n_samples`` and ``levels`` are provided.
         """
-
         if not levels and not n_samples:
             raise ValueError(
                 "Either 'n_samples' or 'levels' is required as an input "
@@ -280,8 +320,9 @@ class DOELibrary(DriverLib, metaclass=GoogleDocstringInheritanceMeta):
         Args:
             doe_output_file: The path to the output file.
         """
-        if self.unit_samples is None:
-            raise RuntimeError("Samples are None, execute method before export.")
+        if not self.unit_samples.size:
+            raise RuntimeError("Samples are missing, execute method before export.")
+
         savetxt(doe_output_file, self.unit_samples, delimiter=",")
 
     def _worker(self, sample: ndarray) -> DOELibraryOutputType:
@@ -385,21 +426,6 @@ class DOELibrary(DriverLib, metaclass=GoogleDocstringInheritanceMeta):
                     )
                     LOGGER.error(traceback.format_exc())
 
-    @staticmethod
-    def is_algorithm_suited(
-        algorithm_description: DOEAlgorithmDescription, problem: OptimizationProblem
-    ) -> bool:
-        """Check if the algorithm is suited to the problem according to its description.
-
-        Args:
-            algorithm_description: The description of the algorithm.
-            problem: The problem to be solved.
-
-        Returns:
-            Whether the algorithm is suited to the problem.
-        """
-        return True
-
     @staticmethod
     def _rescale_samples(samples):
         """When the samples are out of the [0, 1] bounds, rescales them.
