@@ -19,7 +19,6 @@
 """Build a diagonal DOE for scalable model construction."""
 from __future__ import annotations
 
-import logging
 from typing import Container
 from typing import Optional
 from typing import Union
@@ -27,14 +26,13 @@ from typing import Union
 from numpy import hstack
 from numpy import linspace
 from numpy import ndarray
+from numpy import newaxis
 
 from gemseo.algos.doe.doe_lib import DOEAlgorithmDescription
 from gemseo.algos.doe.doe_lib import DOELibrary
 
 OptionType = Optional[Union[str, int, float, bool, Container[str]]]
 
-LOGGER = logging.getLogger(__name__)
-
 
 class DiagonalDOE(DOELibrary):
     """Class used to create a diagonal DOE."""
@@ -42,7 +40,7 @@ class DiagonalDOE(DOELibrary):
     __ALGO_DESC = {"DiagonalDOE": "Diagonal design of experiments"}
     LIBRARY_NAME = "GEMSEO"
 
-    def __init__(self) -> None:
+    def __init__(self) -> None:  # noqa:D107
         super().__init__()
         for algo, description in self.__ALGO_DESC.items():
             self.descriptions[algo] = DOEAlgorithmDescription(
@@ -132,6 +130,6 @@ class DiagonalDOE(DOELibrary):
                 start = 0.0
                 end = 1.0
 
-            samples.append(linspace(start, end, n_samples)[:, None])
+            samples.append(linspace(start, end, n_samples)[:, newaxis])
 
         return hstack(samples)
