@@ -129,7 +129,7 @@ class Nlopt(OptimizationLibrary):
 
     LIBRARY_NAME = "NLopt"
 
-    def __init__(self) -> None:
+    def __init__(self) -> None:  # noqa:D107
         super().__init__()
 
         nlopt_doc = "https://nlopt.readthedocs.io/en/latest/NLopt_Algorithms/"
@@ -346,9 +346,7 @@ class Nlopt(OptimizationLibrary):
             if self.descriptions[self.algo_name].require_gradient:
                 if grad.size > 0:
                     cstr_jac = jac(xn_vect)
-                    grad[:] = atleast_2d(cstr_jac)[
-                        index_cstr,
-                    ]
+                    grad[:] = atleast_2d(cstr_jac)[index_cstr,]
             return atleast_1d(func(xn_vect).real)[index_cstr]
 
         return cstr_fun_grad
