@@ -83,6 +83,7 @@ from numpy import array
 from numpy import array_equal
 from numpy import inf
 from numpy import insert
+from numpy import isnan
 from numpy import issubdtype
 from numpy import multiply
 from numpy import nan
@@ -95,11 +96,14 @@ from numpy.linalg import norm
 from gemseo.algos.aggregation.aggregation_func import aggregate_iks
 from gemseo.algos.aggregation.aggregation_func import aggregate_ks
 from gemseo.algos.aggregation.aggregation_func import aggregate_max
+from gemseo.algos.aggregation.aggregation_func import aggregate_positive_sum_square
 from gemseo.algos.aggregation.aggregation_func import aggregate_sum_square
 from gemseo.algos.database import Database
 from gemseo.algos.design_space import DesignSpace
 from gemseo.algos.opt_result import OptimizationResult
 from gemseo.core.dataset import Dataset
+from gemseo.core.derivatives.derivation_modes import COMPLEX_STEP
+from gemseo.core.derivatives.derivation_modes import FINITE_DIFFERENCES
 from gemseo.core.mdofunctions.mdo_function import MDOFunction
 from gemseo.core.mdofunctions.mdo_linear_function import MDOLinearFunction
 from gemseo.core.mdofunctions.mdo_quadratic_function import MDOQuadraticFunction
@@ -120,6 +124,7 @@ NAME_TO_METHOD = {
     "max": aggregate_max,
     "KS": aggregate_ks,
     "IKS": aggregate_iks,
+    "pos_sum": aggregate_positive_sum_square,
 }
 
 BestInfeasiblePointType = Tuple[
@@ -157,6 +162,12 @@ class OptimizationProblem:
     when analytical gradient is not available.
     """
 
+    current_iter: int
+    """The current iteration."""
+
+    max_iter: int
+    """The maximum iteration."""
+
     nonproc_objective: MDOFunction
     """The non-processed objective function."""
 
@@ -211,13 +222,10 @@ class OptimizationProblem:
     use_standardized_objective: bool
     """Whether to use standardized objective for logging and post-processing.
 
-    The standardized objective corresponds to the original one
-    expressed as a cost function to minimize.
-    A :class:`.DriverLib` works with this standardized objective
-    and the :class:`.Database` stores its values.
-    However, for convenience,
-    it may be more relevant to log the expression
-    and the values of the original objective.
+    The standardized objective corresponds to the original one expressed as a cost
+    function to minimize. A :class:`.DriverLib` works with this standardized objective
+    and the :class:`.Database` stores its values. However, for convenience, it may be
+    more relevant to log the expression and the values of the original objective.
     """
 
     constraint_names: dict[str, list[str]]
@@ -228,8 +236,8 @@ class OptimizationProblem:
     AVAILABLE_PB_TYPES: ClassVar[str] = [LINEAR_PB, NON_LINEAR_PB]
 
     USER_GRAD: Final[str] = "user"
-    COMPLEX_STEP: Final[str] = "complex_step"
-    FINITE_DIFFERENCES: Final[str] = "finite_differences"
+    COMPLEX_STEP: Final[str] = COMPLEX_STEP
+    FINITE_DIFFERENCES: Final[str] = FINITE_DIFFERENCES
     __DIFFERENTIATION_CLASSES: ClassVar[str] = {
         COMPLEX_STEP: ComplexStep,
         FINITE_DIFFERENCES: FirstOrderFD,
@@ -285,7 +293,6 @@ class OptimizationProblem:
         use_standardized_objective: bool = True,
         **parallel_differentiation_options: int | bool,
     ) -> None:
-        # noqa: D205, D212, D415
         """
         Args:
             design_space: The design space on which the functions are evaluated.
@@ -296,12 +303,13 @@ class OptimizationProblem:
             differentiation_method: The default differentiation method to be applied
                 to the functions of the optimization problem.
             fd_step: The step to be used by the step-based differentiation methods.
-            parallel_differentiation: Whether to approximate the derivatives in parallel.
+            parallel_differentiation: Whether to approximate the derivatives in
+            parallel.
             use_standardized_objective: Whether to use standardized objective
                 for logging and post-processing.
             **parallel_differentiation_options: The options
                 to approximate the derivatives in parallel.
-        """
+        """  # noqa: D205, D212, D415
         self._objective = None
         self.nonproc_objective = None
         self.constraints = []
@@ -317,7 +325,7 @@ class OptimizationProblem:
         self.pb_type = pb_type
         self.ineq_tolerance = 1e-4
         self.eq_tolerance = 1e-2
-        self.max_iter = None
+        self.max_iter = 0
         self.current_iter = 0
         self.use_standardized_objective = use_standardized_objective
         self.__functions_are_preprocessed = False
@@ -353,7 +361,7 @@ class OptimizationProblem:
         Returns:
             Whether the maximum amount of iterations has been reached.
         """
-        if self.max_iter is None or self.current_iter is None:
+        if self.max_iter in [None, 0] or self.current_iter in [None, 0]:
             return False
         return self.current_iter >= self.max_iter
 
@@ -371,15 +379,12 @@ class OptimizationProblem:
         self.__parallel_differentiation = value
 
     @property
-    def parallel_differentiation_options(self) -> bool:
+    def parallel_differentiation_options(self) -> dict[str, int | bool]:
         """The options to approximate the derivatives in parallel."""
         return self.__parallel_differentiation_options
 
     @parallel_differentiation_options.setter
-    def parallel_differentiation_options(
-        self,
-        value: bool,
-    ) -> None:
+    def parallel_differentiation_options(self, value: dict[str, int | bool]) -> None:
         self.__raise_exception_if_functions_are_already_preprocessed()
         self.__parallel_differentiation_options = value
 
@@ -397,9 +402,8 @@ class OptimizationProblem:
             value = value[0].decode()
         if value not in self.DIFFERENTIATION_METHODS:
             raise ValueError(
-                "'{}' is not a differentiation methods; available ones are: '{}'.".format(
-                    value, "', '".join(self.DIFFERENTIATION_METHODS)
-                )
+                "'{}' is not a differentiation methods; available ones are: '{"
+                "}'.".format(value, "', '".join(self.DIFFERENTIATION_METHODS))
             )
         self.__differentiation_method = value
 
@@ -519,7 +523,9 @@ class OptimizationProblem:
         if not has_default_name:
             cstr_func.name = func_name
             if cstr_func.outvars:
-                cstr_repr = cstr_repr.replace(func_name, "#".join(cstr_func.outvars))
+                output_names = "#".join(cstr_func.outvars)
+                cstr_repr = cstr_repr.replace(func_name, output_names)
+                cstr_func.expr = cstr_func.expr.replace(func_name, output_names)
                 cstr_func.special_repr = f"{func_name}: {cstr_repr}"
 
         if func_name not in self.constraint_names:
@@ -603,6 +609,66 @@ class OptimizationProblem:
             ecstr = self.constraints[constr_id:]
             self.constraints = icstr + cstrs + ecstr
 
+    def apply_exterior_penalty(
+        self,
+        objective_scale: float = 1.0,
+        scale_inequality: float | ndarray = 1.0,
+        scale_equality: float | ndarray = 1.0,
+    ):
+        r"""Reformulate the optimization problem using exterior penalty.
+
+        Given the optimization problem with equality and inequality constraints:
+
+        .. math::
+
+            min_x f(x)
+
+            s.t.
+
+            g(x)\leq 0
+
+            h(x)=0
+
+            l_b\leq x\leq u_b
+
+        The exterior penalty approach consists in building a penalized objective
+        function that takes into account constraints violations:
+
+        .. math::
+
+            min_x \tilde{f}(x) = \frac{f(x)}{o_s} + s[\sum{H(g(x))g(x)^2}+\sum{h(x)^2}]
+
+            s.t.
+
+            l_b\leq x\leq u_b
+
+        Where :math:`H(x)` is the Heaviside function, :math:`o_s` is the ``objective_scale``
+        parameter and :math:`s` is the scale parameter.
+        The solution of the new problem approximate the one of the original problem.
+        Increasing the values of ``objective_scale`` and scale, the solutions are closer but
+        the optimization problem requires more and more iterations to be solved.
+
+        Args:
+            scale_equality: The equality constraint scaling constant.
+            objective_scale: The objective scaling constant.
+            scale_inequality: The inequality constraint scaling constant.
+        """
+        penalized_objective = self.objective / objective_scale
+        self.add_observable(self.objective)
+        for constr in self.constraints:
+            if constr.f_type == MDOFunction.TYPE_INEQ:
+                penalized_objective += aggregate_positive_sum_square(
+                    constr, scale=scale_inequality
+                )
+            else:
+                penalized_objective += aggregate_sum_square(
+                    constr, scale=scale_equality
+                )
+            self.add_observable(constr)
+        self.objective = penalized_objective
+        self.constraints = []
+        self.constraint_names = {}
+
     def add_observable(
         self,
         obs_func: MDOFunction,
@@ -1318,7 +1384,6 @@ class OptimizationProblem:
             self.__functions_are_preprocessed = True
             self.check()
             self.__eval_obs_jac = eval_obs_jac
-            self.database.add_new_iter_listener(self.execute_observables_callback)
 
     def execute_observables_callback(self, last_x: ndarray) -> None:
         """The callback function to be passed to the database.
@@ -1666,6 +1731,8 @@ class OptimizationProblem:
             if eval_cstr is None:
                 break
             if not self._satisfied_constraint(constraint.f_type, eval_cstr):
+                if isnan(eval_cstr).any():
+                    return False, inf
                 is_pt_feasible = False
                 if constraint.f_type == MDOFunction.TYPE_INEQ:
                     if isinstance(eval_cstr, ndarray):
@@ -1717,6 +1784,9 @@ class OptimizationProblem:
             outputs_opt = f_history[best_i]
             x_opt = x_history[best_i]
             f_opt = outputs_opt.get(self.objective.name)
+        if isinstance(f_opt, ndarray):
+            if len(f_opt) == 1:
+                f_opt = f_opt[0]
 
         return x_opt, f_opt, is_opt_feasible, outputs_opt
 
@@ -1774,7 +1844,7 @@ class OptimizationProblem:
         c_opt_grad = {}
         obj_name = self.objective.name
         constraints = self.get_ineq_constraints() + self.get_eq_constraints()
-        for (i, out_val) in enumerate(feas_f):
+        for i, out_val in enumerate(feas_f):
             obj_eval = out_val.get(obj_name)
             if obj_eval is None or isinstance(obj_eval, Number) or obj_eval.size == 1:
                 tmp_objeval = obj_eval
@@ -1788,6 +1858,9 @@ class OptimizationProblem:
                     c_opt[c_name] = feas_f[i].get(c_name)
                     c_key = Database.get_gradient_name(c_name)
                     c_opt_grad[constraint.name] = feas_f[i].get(c_key)
+        if isinstance(f_opt, ndarray):
+            if len(f_opt) == 1:
+                f_opt = f_opt[0]
         return x_opt, f_opt, c_opt, c_opt_grad
 
     def get_optimum(self) -> OptimumType:
@@ -1977,7 +2050,7 @@ class OptimizationProblem:
         design_space = DesignSpace(file_path)
         opt_pb = OptimizationProblem(design_space, input_database=file_path)
 
-        with h5py.File(file_path, "r") as h5file:
+        with h5py.File(file_path) as h5file:
             group = get_hdf5_group(h5file, opt_pb.OPT_DESCR_GROUP)
 
             for attr_name, attr in group.items():
@@ -1996,7 +2069,7 @@ class OptimizationProblem:
             # The generated functions can be called at the x stored in
             # the database
             attr.set_pt_from_database(
-                opt_pb.database, design_space, jac=True, x_tolerance=x_tolerance
+                opt_pb.database, design_space, x_tolerance=x_tolerance
             )
             opt_pb.objective = attr
 
@@ -2100,8 +2173,8 @@ class OptimizationProblem:
         input_history = split_array_to_dict_of_arrays(
             input_history, names_to_sizes, input_names
         )
-        for input_name, input_value in sorted(input_history.items()):
-            dataset.add_variable(input_name, input_value, input_group)
+        for input_name, input_value in input_history.items():
+            dataset.add_variable(input_name, input_value.real, input_group)
 
         # Add database outputs
         variable_names = self.database.get_all_data_names(skip_iter=True)
@@ -2163,7 +2236,7 @@ class OptimizationProblem:
 
             dataset.add_variable(
                 output_name,
-                output_history.reshape((n_samples, -1)),
+                output_history.reshape((n_samples, -1)).real,
                 output_group,
                 cache_as_input=cache_output_as_input,
             )
@@ -2203,7 +2276,7 @@ class OptimizationProblem:
 
             dataset.add_variable(
                 Database.get_gradient_name(output_name),
-                gradient_history.reshape(n_samples, -1),
+                gradient_history.reshape(n_samples, -1).real,
                 gradient_group,
                 cache_as_input=cache_output_as_input,
             )
@@ -2474,7 +2547,7 @@ class OptimizationProblem:
         Args:
             name: The name of the constraint.
             from_original_constraints: Whether to get the constraint from the original
-                constraints; otherwise get the constraint from the the pre-processed
+                constraints; otherwise get the constraint from the pre-processed
                 constraints.
 
         Returns:
