@@ -16,10 +16,7 @@
 #    INITIAL AUTHORS - API and implementation and/or documentation
 #        :author: Francois Gallard
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
-"""
-Various termination criteria for drivers
-****************************************
-"""
+"""Various termination criteria for drivers."""
 from __future__ import annotations
 
 from numpy import all
@@ -40,26 +37,25 @@ class DesvarIsNan(TerminationCriterion):
 
 
 class MaxIterReachedException(TerminationCriterion):
-    """Exception raised when the maximum number of iterations is reached by the
-    driver."""
+    """Exception raised when the maximum number of iterations is reached."""
 
 
 class MaxTimeReached(TerminationCriterion):
-    """Exception raised when the maximum execution time is reached by the driver."""
+    """Exception raised when the maximum execution time is reached."""
 
 
 class FtolReached(TerminationCriterion):
-    """Exception raised when the f_tol_rel or f_tol_abs criteria is reached by the
-    driver."""
+    """Exception raised when the f_tol_rel or f_tol_abs criteria is reached."""
 
 
 class XtolReached(TerminationCriterion):
-    """Exception raised when the x_tol_rel or x_tol_abs criteria is reached by the
-    driver."""
+    """Exception raised when the x_tol_rel or x_tol_abs criteria is reached."""
 
 
 def is_x_tol_reached(opt_problem, x_tol_rel=1e-6, x_tol_abs=1e-6, n_x=2):
-    """Tests if the tolerance on the design variables are reached The coordinate wise
+    """Tests if the tolerance on the design variables are reached.
+
+    The coordinate wise
     average of the last n_x points are taken Then it is checked that all points are
     within the distance of the center with relative and absolute tolerances specified by
     the user.
@@ -95,7 +91,9 @@ def is_x_tol_reached(opt_problem, x_tol_rel=1e-6, x_tol_abs=1e-6, n_x=2):
 
 
 def is_f_tol_reached(opt_problem, f_tol_rel=1e-6, f_tol_abs=1e-6, n_x=2):
-    """Tests if the tolerance on the objective function are reached The average function
+    """Tests if the tolerance on the objective function are reached.
+
+    The average function
     value of the last n_x points are taken Then it is checked that all points are within
     the distance of the center with relative and absolute tolerances specified by the
     user.
@@ -104,9 +102,9 @@ def is_f_tol_reached(opt_problem, f_tol_rel=1e-6, f_tol_abs=1e-6, n_x=2):
     ----------
     opt_problem: OptimizationProblem
         the optimization problem containing the iterations
-    x_tol_rel: float
+    f_tol_rel: float
         relative tolerance
-    x_tol_abs: float
+    f_tol_abs: float
         absolute tolerance
     n_x: int
         number of design vectors to account for
