@@ -49,9 +49,7 @@ from numpy import vstack
 from xxhash import xxh3_64_hexdigest
 
 from gemseo.core.discipline_data import Data
-from gemseo.utils.data_conversion import concatenate_dict_of_arrays_to_array
 from gemseo.utils.data_conversion import flatten_nested_bilevel_dict
-from gemseo.utils.data_conversion import split_array_to_dict_of_arrays
 from gemseo.utils.ggobi_export import save_data_arrays_to_xml
 from gemseo.utils.locks import synchronized
 from gemseo.utils.locks import synchronized_hashes
@@ -123,6 +121,10 @@ class AbstractCache(ABCMapping):
         accessible either by index, e.g. ``input_data = cache_entry[0]``,
         or by name, e.g. ``input_data = cache_entry.inputs``.
 
+    Note:
+        If an output name is also an input name,
+        the output name is suffixed with ``[out]``.
+
     One can also get the number of cache entries with ``size = len(cache)``
     and iterate over the cache,
     e.g. ``for input_data, output_data, _ in cache``
@@ -166,7 +168,7 @@ class AbstractCache(ABCMapping):
                 It could be something like ``2 * numpy.finfo(float).eps``.
             name: A name for the cache.
                 If ``None``, use the class name.
-        """
+        """  # noqa: D205, D212, D415
         self.tolerance = tolerance
         self.name = name if name is not None else self.__class__.__name__
         self.__names_to_sizes = {}
@@ -309,6 +311,8 @@ class AbstractCache(ABCMapping):
                 If ``None``, use all the inputs.
             output_names: The names of the outputs to be exported.
                 If ``None``, use all the outputs.
+                If an output name is also an input name,
+                the output name is suffixed with ``[out]``.
 
         Returns:
             A dataset version of the cache.
@@ -328,38 +332,74 @@ class AbstractCache(ABCMapping):
             output_group = dataset.OUTPUT_GROUP
             cache_output_as_input = False
 
-        # Add cache inputs and outputs
-        inputs = vstack(
-            [
-                concatenate_dict_of_arrays_to_array(data.inputs, input_names)
-                for data in self
-                if data.outputs
-            ]
+        self.__fill_dataset_by_group(
+            dataset,
+            input_names,
+            input_group,
+            input_names,
+            cache_output_as_input,
+            is_output_group=False,
         )
-        data = split_array_to_dict_of_arrays(inputs, self.names_to_sizes, input_names)
-        for input_name, value in sorted(data.items()):
-            dataset.add_variable(input_name, value, input_group)
-
-        outputs = vstack(
-            [
-                concatenate_dict_of_arrays_to_array(data.outputs, output_names)
-                for data in self
-                if data.outputs
-            ]
+        self.__fill_dataset_by_group(
+            dataset,
+            output_names,
+            output_group,
+            input_names,
+            cache_output_as_input,
+            is_output_group=True,
         )
-        data = split_array_to_dict_of_arrays(outputs, self.names_to_sizes, output_names)
-        for output_name, value in sorted(data.items()):
-            dataset.add_variable(
-                output_name, value, output_group, cache_as_input=cache_output_as_input
-            )
 
         return dataset
 
+    def __fill_dataset_by_group(
+        self,
+        dataset: Dataset,
+        names: list[str],
+        group: str,
+        input_names: list[str],
+        cache_output_as_input: bool,
+        is_output_group: bool,
+    ) -> None:
+        """Fill a group of a dataset with cache variables.
+
+        If the same variable name occurs in the input and the output,
+        suffix the output name to make it unique.
+
+        Args:
+            dataset: The dataset to be filled.
+            names: The variable names of the group to be added to the dataset.
+            group: The group of variables to be added to the dataset.
+            input_names: The names of the cached input variables to be added to the
+                dataset.
+            cache_output_as_input: Whether the output variables are added as input ones.
+            is_output_group: Whether ``group`` is a group of output variables.
+        """
+        for name in names:
+            cache_entries = []
+            for cache_entry in self:
+                if cache_entry.outputs:
+                    if is_output_group:
+                        selected_cache_entry = cache_entry.outputs[name]
+                    else:
+                        selected_cache_entry = cache_entry.inputs[name]
+                    cache_entries.append(selected_cache_entry)
+            data = vstack(cache_entries)
+            if is_output_group:
+                if name in input_names:
+                    final_name = f"{name}[out]"
+                else:
+                    final_name = name
+                dataset.add_variable(
+                    final_name, data, group, cache_as_input=cache_output_as_input
+                )
+            else:
+                dataset.add_variable(name, data, group)
+
 
 class AbstractFullCache(AbstractCache):
     """Abstract cache to store all the data, either in memory or on the disk.
 
-    See also:
+    See Also:
         :class:`.MemoryFullCache`: store all the data in memory.
         :class:`.HDF5Cache`: store all the data in an HDF5 file.
     """
@@ -391,7 +431,7 @@ class AbstractFullCache(AbstractCache):
     _last_accessed_index: Value
     """The index of the last accessed data."""
 
-    def __init__(
+    def __init__(  # noqa: D107
         self,
         tolerance: float = 0.0,
         name: str | None = None,
@@ -535,7 +575,7 @@ class AbstractFullCache(AbstractCache):
         return False
 
     @synchronized
-    def cache_outputs(
+    def cache_outputs(  # noqa: D102
         self,
         input_data: Data,
         output_data: Data,
@@ -551,7 +591,7 @@ class AbstractFullCache(AbstractCache):
         )
 
     @synchronized
-    def cache_jacobian(
+    def cache_jacobian(  # noqa: D102
         self,
         input_data: Data,
         jacobian_data: JacobianData,
@@ -571,7 +611,7 @@ class AbstractFullCache(AbstractCache):
         )
 
     @synchronized
-    def clear(self) -> None:
+    def clear(self) -> None:  # noqa: D102
         super().clear()
         self._hashes_to_indices.clear()
         self._max_index.value = 0
@@ -579,7 +619,7 @@ class AbstractFullCache(AbstractCache):
 
     @property
     @synchronized
-    def last_entry(self) -> CacheEntry:
+    def last_entry(self) -> CacheEntry:  # noqa: D102
         if not self:
             return CacheEntry({}, {}, {})
 
@@ -784,7 +824,7 @@ class AbstractFullCache(AbstractCache):
         Args:
             other_cache: The cache to update the current one.
         """
-        for (input_data, output_data, jacobian_data) in other_cache:
+        for input_data, output_data, jacobian_data in other_cache:
             if output_data or jacobian_data:
                 self[input_data] = (output_data, jacobian_data)
 
