@@ -50,14 +50,15 @@ from numpy import zeros
 from gemseo.caches.cache_factory import CacheFactory
 from gemseo.core.cache import AbstractCache
 from gemseo.core.data_processor import DataProcessor
+from gemseo.core.derivatives import derivation_modes
 from gemseo.core.discipline_data import DisciplineData
 from gemseo.core.discipline_data import MutableData
 from gemseo.core.grammars.base_grammar import BaseGrammar
 from gemseo.core.grammars.errors import InvalidDataException
 from gemseo.core.grammars.factory import GrammarFactory
-from gemseo.core.jacobian_assembly import JacobianAssembly
 from gemseo.core.namespaces import remove_prefix_from_dict
 from gemseo.core.namespaces import remove_prefix_from_list
+from gemseo.disciplines.utils import get_sub_disciplines
 from gemseo.utils.derivatives.derivatives_approx import DisciplineJacApprox
 from gemseo.utils.derivatives.derivatives_approx import EPSILON
 from gemseo.utils.multiprocessing import get_multi_processing_manager
@@ -113,16 +114,17 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
     """The policy to re-execute the same discipline."""
 
     residual_variables: Mapping[str, str]
-    """The output variables mapping to their inputs,
-    to be considered as residuals; they shall be equal to zero.
-    """
+    """The output variables mapping to their inputs, to be considered as residuals; they
+    shall be equal to zero."""
 
     run_solves_residuals: bool
     """If True, the run method shall solve the residuals."""
 
     jac: dict[str, dict[str, ndarray]]
-    """The Jacobians of the outputs wrt inputs
-    of the form ``{output: {input: matrix}}``."""
+    """The Jacobians of the outputs wrt inputs of the form ``{output: {input:
+
+    matrix}}``.
+    """
 
     exec_for_lin: bool
     """Whether the last execution was due to a linearization."""
@@ -130,21 +132,23 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
     name: str
     """The name of the discipline."""
 
-    cache: AbstractCache
-    """The cache containing one or several executions of the discipline
-    according to the cache policy."""
+    cache: AbstractCache | None
+    """The cache containing one or several executions of the discipline according to the
+    cache policy."""
 
     STATUS_VIRTUAL = "VIRTUAL"
     STATUS_PENDING = "PENDING"
     STATUS_DONE = "DONE"
     STATUS_RUNNING = "RUNNING"
     STATUS_FAILED = "FAILED"
+    STATUS_LINEARIZE = "LINEARIZE"
     AVAILABLE_STATUSES = [
         STATUS_DONE,
         STATUS_FAILED,
         STATUS_PENDING,
         STATUS_RUNNING,
         STATUS_VIRTUAL,
+        STATUS_LINEARIZE,
     ]
 
     JSON_GRAMMAR_TYPE = "JSONGrammar"
@@ -153,8 +157,8 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
     GRAMMAR_DIRECTORY: ClassVar[str | None] = None
     """The directory in which to search for the grammar files if not the class one."""
 
-    COMPLEX_STEP = "complex_step"
-    FINITE_DIFFERENCES = "finite_differences"
+    COMPLEX_STEP = derivation_modes.COMPLEX_STEP
+    FINITE_DIFFERENCES = derivation_modes.FINITE_DIFFERENCES
 
     SIMPLE_CACHE = "SimpleCache"
     HDF5_CACHE = "HDF5Cache"
@@ -165,12 +169,12 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
 
     APPROX_MODES = [FINITE_DIFFERENCES, COMPLEX_STEP]
     AVAILABLE_MODES = (
-        JacobianAssembly.AUTO_MODE,
-        JacobianAssembly.DIRECT_MODE,
-        JacobianAssembly.ADJOINT_MODE,
-        JacobianAssembly.REVERSE_MODE,
-        FINITE_DIFFERENCES,
-        COMPLEX_STEP,
+        derivation_modes.AUTO_MODE,
+        derivation_modes.DIRECT_MODE,
+        derivation_modes.ADJOINT_MODE,
+        derivation_modes.REVERSE_MODE,
+        derivation_modes.FINITE_DIFFERENCES,
+        derivation_modes.COMPLEX_STEP,
     )
 
     RE_EXECUTE_DONE_POLICY = "RE_EXEC_DONE"
@@ -201,6 +205,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         "_status",
         "cache",
         "data_processor",
+        "_disciplines",
         "exec_for_lin",
         "exec_time",
         "input_grammar",
@@ -255,15 +260,13 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
                 or :attr:`.MDODiscipline.SIMPLE_GRAMMAR_TYPE`.
             cache_type: The type of policy to cache the discipline evaluations,
                 e.g. :attr:`.MDODiscipline.SIMPLE_CACHE` to cache the last one,
-                :attr:`.MDODiscipline.HDF5_CACHE` to cache them in a HDF file,
+                :attr:`.MDODiscipline.HDF5_CACHE` to cache them in an HDF file,
                 or :attr:`.MDODiscipline.MEMORY_FULL_CACHE` to cache them in memory.
                 If ``None`` or if :attr:`.activate_cache` is ``True``,
                 do not cache the discipline evaluations.
             cache_file_path: The HDF file path
                 when ``grammar_type`` is :attr:`.MDODiscipline.HDF5_CACHE`.
-        """
-
-        # : data converters between execute and _run
+        """  # noqa: D205, D212, D415
         self.data_processor = None
         self._default_inputs = None
         self.input_grammar = None
@@ -275,6 +278,8 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         # : list of outputs that shall be null, to be considered as residuals
         self.residual_variables = {}
 
+        self._disciplines = []
+
         self.run_solves_residuals = False
 
         self._differentiated_inputs = []  # : outputs to differentiate
@@ -285,10 +290,10 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         # : number of calls to linearize()
         self._n_calls_linearize = None
         self._in_data_hash_dict = {}
-        self.jac = None  # : Jacobians of outputs wrt inputs dictionary
+        self.jac = {}  # : Jacobians of outputs wrt inputs dictionary
         # : True if linearize() has already been called
         self._is_linearized = False
-        self._jac_approx = None  # Jacobian approximation object
+        self._jac_approx = None  # Jacobian's approximation object
         self._linearize_on_last_state = False  # If true, the linearization
         # is performed on the state computed by the disciplines
         # (MDAs for instance) otherwise, the inputs that are also outputs
@@ -314,13 +319,13 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         self._cache_was_loaded = False
 
         # linearize mode :auto, adjoint, direct
-        self._linearization_mode = JacobianAssembly.AUTO_MODE
+        self._linearization_mode = derivation_modes.AUTO_MODE
 
         self._grammar_type = grammar_type
 
         if auto_detect_grammar_files:
             if input_grammar_file is None:
-                input_grammar_file = self.auto_get_grammar_file(is_input=True)
+                input_grammar_file = self.auto_get_grammar_file()
 
             if output_grammar_file is None:
                 output_grammar_file = self.auto_get_grammar_file(is_input=False)
@@ -332,7 +337,6 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         self._local_data = None
         self.__set_local_data({})
 
-        # : The current status of execution
         self._status = self.STATUS_PENDING
         if self.activate_counters:
             self._init_shared_attrs()
@@ -356,6 +360,11 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         self._exec_time = Value("d", 0.0)
         self._n_calls_linearize = Value("i", 0)
 
+    @property
+    def disciplines(self) -> list[MDODiscipline]:
+        """The sub-disciplines, if any."""
+        return self._disciplines
+
     @property
     def local_data(self) -> DisciplineData:
         """The current input and output data."""
@@ -439,7 +448,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         self._n_calls_linearize.value = value
 
     @property
-    def grammar_type(self) -> BaseGrammar:
+    def grammar_type(self) -> str:
         """The type of grammar to be used for inputs and outputs declaration."""
         return self._grammar_type
 
@@ -517,9 +526,16 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         self,
         inputs: Iterable[str] | None = None,
     ) -> None:
-        """Add inputs against which to differentiate the outputs.
+        """Add the inputs against which to differentiate the outputs.
 
-        This method updates :attr:`.MDODiscipline._differentiated_inputs` with ``inputs``.
+        If the discipline grammar type is :attr:`.MDODiscipline.JSON_GRAMMAR_TYPE` and
+        an input is either a non-numeric array or not an array, it will be ignored.
+        If an input is declared as an array but the type of its items is not defined, it
+        is assumed as a numeric array.
+
+        If the discipline grammar type is :attr:`.MDODiscipline.SIMPLE_GRAMMAR_TYPE` and
+        an input is not an array, it will be ignored. Keep in mind that in this case
+        the array subtype is not checked.
 
         Args:
             inputs: The input variables against which to differentiate the outputs.
@@ -531,14 +547,18 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         """
         if (inputs is not None) and (not self.is_all_inputs_existing(inputs)):
             raise ValueError(
-                "Cannot differentiate the discipline {} wrt the inputs "
-                "that are not among the discipline inputs: {}.".format(
-                    self.name, self.get_input_data_names()
-                )
+                f"Cannot differentiate the discipline {self.name} w.r.t. the inputs "
+                "that are not among the discipline inputs: "
+                f"{self.get_input_data_names()}."
             )
 
         if inputs is None:
             inputs = self.get_input_data_names()
+
+        inputs = [
+            input_ for input_ in inputs if self.input_grammar.is_array(input_, True)
+        ]
+
         in_diff = self._differentiated_inputs
         self._differentiated_inputs = list(set(in_diff).union(inputs))
 
@@ -546,9 +566,16 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         self,
         outputs: Iterable[str] | None = None,
     ) -> None:
-        """Add outputs to be differentiated.
+        """Add the outputs to be differentiated.
 
-        This method updates :attr:`.MDODiscipline._differentiated_outputs` with ``outputs``.
+        If the discipline grammar type is :attr:`.MDODiscipline.JSON_GRAMMAR_TYPE` and
+        an output is either a non-numeric array or not an array, it will be ignored.
+        If an output is declared as an array but the type of its items is not defined,
+        it is assumed as a numeric array.
+
+        If the discipline grammar type is :attr:`.MDODiscipline.SIMPLE_GRAMMAR_TYPE` and
+        an output is not an array, it will be ignored. Keep in mind that in this case
+        the array subtype is not checked.
 
         Args:
             outputs: The output variables to be differentiated.
@@ -559,15 +586,19 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         """
         if (outputs is not None) and (not self.is_all_outputs_existing(outputs)):
             raise ValueError(
-                "Cannot differentiate {} "
-                "that are not among the discipline outputs {}.".format(
-                    self.name, self.get_output_data_names()
-                )
+                f"Cannot differentiate the discipline {self.name} w.r.t. the outputs "
+                "that are not among the discipline outputs: "
+                f"{self.get_output_data_names()}."
             )
 
         out_diff = self._differentiated_outputs
         if outputs is None:
             outputs = self.get_output_data_names()
+
+        outputs = [
+            output for output in outputs if self.output_grammar.is_array(output, True)
+        ]
+
         self._differentiated_outputs = list(set(out_diff).union(outputs))
 
     def __create_new_cache(
@@ -645,7 +676,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         if self.cache.__class__.__name__ != cache_type or not (
             cache_type == self.HDF5_CACHE
             and cache_hdf_file == self.cache.hdf_file.hdf_file_path
-            and cache_hdf_node_name == self.cache.node_path
+            and cache_hdf_node_name == self.cache.hdf_node_name
         ):
             self.cache = self.__create_new_cache(
                 cache_type,
@@ -656,20 +687,36 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
             )
         else:
             LOGGER.warning(
-                "Cache policy is set to %s: call clear() to clear a "
-                "discipline cache",
+                (
+                    "The cache policy is already set to %s "
+                    "with the file path %r and node name %r; "
+                    "call discipline.cache.clear() to clear the cache."
+                ),
                 cache_type,
+                cache_hdf_file,
+                cache_hdf_node_name,
             )
 
-    def get_sub_disciplines(
-        self,
-    ) -> list[MDODiscipline]:  # pylint: disable=R0201
-        """Return the sub-disciplines if any.
+    def get_sub_disciplines(self, recursive: bool = False) -> list[MDODiscipline]:
+        """Determine the sub-disciplines.
+
+        This method lists the sub-disciplines' disciplines. It will list up to one level
+        of disciplines contained inside another one unless the ``recursive`` argument is
+        set to ``True``.
+
+        Args:
+            recursive: If ``True``, the method will look inside any discipline that has
+                other disciplines inside until it reaches a discipline without
+                sub-disciplines, in this case the return value will not include any
+                discipline that has sub-disciplines. If ``False``, the method will list
+                up to one level of disciplines contained inside another one, in this
+                case the return value may include disciplines that contain
+                sub-disciplines.
 
         Returns:
             The sub-disciplines.
         """
-        return []
+        return get_sub_disciplines(self._disciplines, recursive)
 
     def get_expected_workflow(self) -> SerialExecSequence:
         """Return the expected execution sequence.
@@ -710,12 +757,10 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         return []
 
     def get_disciplines_in_dataflow_chain(self) -> list[MDODiscipline]:
-        """Return the disciplines that must be shown as blocks within the XDSM
-        representation of a chain.
+        """Return the disciplines that must be shown as blocks in the XDSM.
 
         By default, only the discipline itself is shown.
-        This function can be differently implemented for
-        any type of inherited discipline.
+        This function can be differently implemented for any type of inherited discipline.
 
         Returns:
             The disciplines shown in the XDSM chain.
@@ -824,30 +869,19 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
 
         Raises:
             ValueError:
-                When the re-execution policy is unknown.
-                When the discipline status and the re-execution policy
-                are no consistent.
+                When the discipline status and the re-execution policy are no consistent.
         """
-        status_ok = True
-        if self.status == self.STATUS_RUNNING:
-            status_ok = False
-        if self.re_exec_policy == self.RE_EXECUTE_NEVER_POLICY:
-            if self.status not in [self.STATUS_PENDING, self.STATUS_VIRTUAL]:
-                status_ok = False
-        elif self.re_exec_policy == self.RE_EXECUTE_DONE_POLICY:
-            if self.status == self.STATUS_DONE:
-                self.reset_statuses_for_run()
-                status_ok = True
-            elif self.status not in [self.STATUS_PENDING, self.STATUS_VIRTUAL]:
-                status_ok = False
-        else:
-            raise ValueError(f"Unknown re_exec_policy: {self.re_exec_policy}.")
-        if not status_ok:
+        if self.status not in [
+            self.STATUS_PENDING,
+            self.STATUS_VIRTUAL,
+            self.STATUS_DONE,
+        ] or (
+            self.status == self.STATUS_DONE
+            and self.re_exec_policy == self.RE_EXECUTE_NEVER_POLICY
+        ):
             raise ValueError(
-                "Trying to run a discipline {} with status: {} "
-                "while re_exec_policy is {}.".format(
-                    type(self), self.status, self.re_exec_policy
-                )
+                f"Trying to run a discipline {type(self)} with status: {self.status} "
+                f"while re_exec_policy is {self.re_exec_policy}."
             )
 
     def __get_input_data_for_cache(
@@ -912,7 +946,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
 
         Raises:
             RuntimeError: When residual_variables are declared but
-                self.run_solves_residuals is False. This is not suported yet.
+                self.run_solves_residuals is False. This is not supported yet.
         """
         if self.residual_variables and not self.run_solves_residuals:
             raise RuntimeError(
@@ -936,8 +970,6 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
             # Save the state of the inputs
             cached_inputs = self.__get_input_data_for_cache(input_data, in_names)
 
-        self._check_status_before_run()
-
         if self.activate_input_data_check:
             self.check_input_data(input_data)
 
@@ -947,13 +979,15 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         else:
             self.__set_local_data(input_data)
 
-        self.status = self.STATUS_RUNNING
         self._is_linearized = False
         if self.activate_counters:
             self.__increment_n_calls()
 
         t_0 = timer()
 
+        self._check_status_before_run()
+        self.status = self.STATUS_RUNNING
+
         try:
             # Effectively run the discipline, the _run method has to be
             # Defined by the subclasses
@@ -964,11 +998,11 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
             # raise the same exception
             raise
 
+        self.status = self.STATUS_DONE
+
         if self.activate_counters:
             self.__increment_exec_time(t_0)
 
-        self.status = self.STATUS_DONE
-
         # If the data processor is set, post process the data after _run
         # See gemseo.core.data_processor module
         if processor is not None:
@@ -1014,7 +1048,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
             self.jac = out_jac
             self._is_linearized = True
         else:  # Erase jacobian which is unknown
-            self.jac = None
+            self.jac.clear()
             self._is_linearized = False
 
         self.check_output_data()
@@ -1094,7 +1128,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
 
     def linearize(
         self,
-        input_data: dict[str, Any] | None = None,
+        input_data: Mapping[str, Any] | None = None,
         force_all: bool = False,
         force_no_exec: bool = False,
     ) -> dict[str, dict[str, ndarray]]:
@@ -1119,7 +1153,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         # is set to True
         inputs, outputs = self._retrieve_diff_inouts(force_all)
         if not outputs:
-            self.jac = {}
+            self.jac.clear()
             return self.jac
         # Save inputs dict for caching
         input_data = self._filter_inputs(input_data)
@@ -1157,10 +1191,11 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
                     # triggered.
                     pass
 
-        t_0 = timer()
-        approximate_jac = self.linearization_mode in self.APPROX_MODES
+        self.status = self.STATUS_LINEARIZE
 
-        if approximate_jac:  # Time already counted in execute()
+        t_0 = timer()
+        if self._linearization_mode in self.APPROX_MODES:
+            # Time already counted in execute()
             self.jac = self._jac_approx.compute_approx_jac(outputs, inputs)
         else:
             self._compute_jacobian(inputs, outputs)
@@ -1176,6 +1211,8 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
             # Cache the Jacobian matrix
             self.cache.cache_jacobian(input_data, self.jac)
 
+        self.status = self.STATUS_DONE
+
         return self.jac
 
     def set_jacobian_approximation(
@@ -1313,7 +1350,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
                 When outputs are missing in the Jacobian of the discipline.
                 When inputs are missing for an output in the Jacobian of the discipline.
         """
-        if self.jac is None:
+        if not self.jac:
             raise ValueError(f"The discipline {self.name} was not linearized.")
         out_set = set(outputs)
         in_set = set(inputs)
@@ -1512,7 +1549,6 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
                 just fill the missing items with zeros/empty
                 but do not override the existing data.
         """
-
         if inputs is None:
             inputs_names = self._differentiated_inputs
         else:
@@ -1682,7 +1718,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
             outputs = self.get_output_data_names()
 
         if auto_set_step:
-            approx.auto_set_step(outputs, inputs, print_errors=True)
+            approx.auto_set_step(outputs, inputs)
 
         # Differentiate analytically
         self.add_differentiated_inputs(inputs)
@@ -1710,7 +1746,13 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
 
     @property
     def status(self) -> str:
-        """The status of the discipline."""
+        """The status of the discipline.
+
+        The status aims at monitoring the process and give the user a simplified view on
+        the state (the process state = execution or linearize or done) of the
+        disciplines. The core part of the execution is _run, the core part of linearize
+        is _compute_jacobian or approximate jacobian computation.
+        """
         return self._status
 
     def _check_status(
@@ -1722,13 +1764,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         Raises:
             ValueError: When the status is unknown.
         """
-        if status not in [
-            self.STATUS_PENDING,
-            self.STATUS_VIRTUAL,
-            self.STATUS_DONE,
-            self.STATUS_RUNNING,
-            self.STATUS_FAILED,
-        ]:
+        if status not in self.AVAILABLE_STATUSES:
             raise ValueError(f"Unknown status: {status}.")
 
     def set_disciplines_statuses(
@@ -1819,7 +1855,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
         Returns:
             Whether the discipline can be run again.
         """
-        return status not in [self.STATUS_RUNNING]
+        return status != self.STATUS_RUNNING
 
     def reset_statuses_for_run(self) -> None:
         """Set all the statuses to :attr:`.MDODiscipline.STATUS_PENDING`.
@@ -2006,7 +2042,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
             The names of the input variables.
         """
         if with_namespaces:
-            return self.input_grammar.keys()
+            return list(self.input_grammar.keys())
         else:
             return remove_prefix_from_list(self.input_grammar.keys())
 
@@ -2021,7 +2057,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
             The names of the output variables.
         """
         if with_namespaces:
-            return self.output_grammar.keys()
+            return list(self.output_grammar.keys())
         else:
             return remove_prefix_from_list(self.output_grammar.keys())
 
@@ -2075,7 +2111,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
             output_names = self.output_grammar.keys()
             return {k: v for k, v in self._local_data.items() if k in output_names}
         else:
-            return remove_prefix_from_dict(self.get_output_data(True))
+            return remove_prefix_from_dict(self.get_output_data())
 
     def get_input_data(self, with_namespaces=True) -> dict[str, Any]:
         """Return the local input data as a dictionary.
@@ -2091,7 +2127,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
             input_names = self.input_grammar.keys()
             return {k: v for k, v in self._local_data.items() if k in input_names}
         else:
-            return remove_prefix_from_dict(self.get_input_data(True))
+            return remove_prefix_from_dict(self.get_input_data())
 
     def serialize(
         self,
@@ -2179,7 +2215,7 @@ class MDODiscipline(metaclass=GoogleDocstringInheritanceMeta):
 
     def __setstate__(
         self,
-        state: dict[str, Any],
+        state: Mapping[str, Any],
     ) -> None:
         self._init_shared_attrs()
         self._status_observers = []
