@@ -16,6 +16,7 @@
 #    INITIAL AUTHORS - API and implementation and/or documentation
 #        :author: Charlie Vanaret
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
+#        :author: Jean-Christophe Giret
 """An advanced MDA splitting algorithm based on graphs."""
 from __future__ import annotations
 
@@ -33,6 +34,7 @@ from numpy import array
 
 from gemseo.api import create_mda
 from gemseo.core.chain import MDOChain
+from gemseo.core.chain import MDOParallelChain
 from gemseo.core.coupling_structure import MDOCouplingStructure
 from gemseo.core.discipline import MDODiscipline
 from gemseo.core.execution_sequence import SerialExecSequence
@@ -83,6 +85,8 @@ class MDAChain(MDA):
         log_convergence: bool = False,
         linear_solver: str = "DEFAULT",
         linear_solver_options: Mapping[str, Any] = None,
+        mdachain_parallelize_tasks: bool = False,
+        mdachain_parallel_options: Mapping[str, int | bool] | None = None,
         **inner_mda_options: float | int | bool | str | None,
     ):
         """
@@ -95,8 +99,13 @@ class MDAChain(MDA):
                 Otherwise, linearize the overall MDA with base class method.
                 This last option is preferred to minimize computations in adjoint mode,
                 while in direct mode, linearizing the chain may be cheaper.
-            sub_coupling_structures: The coupling structures to be used by the inner-MDAs.
+            sub_coupling_structures: The coupling structures to be used by the
+                inner-MDAs.
                 If None, they are created from the sub-disciplines.
+            mdachain_parallelize_tasks: Whether to parallelize the
+                parallel tasks, if any.
+            mdachain_parallel_options: The options of the MDOParallelChain
+                instances, if any.
             **inner_mda_options: The options of the inner-MDAs.
         """
         self.n_processes = n_processes
@@ -126,6 +135,8 @@ class MDAChain(MDA):
             disciplines,
             inner_mda_name=inner_mda_name,
             sub_coupling_structures=sub_coupling_structures,
+            mdachain_parallelize_tasks=mdachain_parallelize_tasks,
+            mdachain_parallel_options=mdachain_parallel_options,
             **inner_mda_options,
         )
 
@@ -154,6 +165,8 @@ class MDAChain(MDA):
         disciplines: Sequence[MDODiscipline],
         inner_mda_name: str = "MDAJacobi",
         sub_coupling_structures: Iterable[MDOCouplingStructure] | None = None,
+        mdachain_parallelize_tasks: bool = False,
+        mdachain_parallel_options: Mapping[str, int | bool | None] = None,
         **inner_mda_options: float | int | bool | str | None,
     ):
         """Create an MDO chain from the execution sequence of the disciplines.
@@ -161,65 +174,276 @@ class MDAChain(MDA):
         Args:
             inner_mda_name: The name of the class of the inner-MDAs.
             disciplines: The disciplines.
-            sub_coupling_structures: The coupling structures to be used by the inner-MDAs.
+            sub_coupling_structures: The coupling structures to be used by the
+                inner-MDAs.
                 If None, they are created from the sub-disciplines.
+            mdachain_parallelize_tasks: Whether to parallelize the
+                parallel tasks,
+                if any.
+            mdachain_parallel_options: The options of the MDOParallelChain instances,
+                if any.
             **inner_mda_options: The options of the inner-MDAs.
         """
-        chained_disciplines = []
-        self.inner_mdas = []
-
         if sub_coupling_structures is None:
             sub_coupling_structures = repeat(None)
+        self.__sub_coupling_structures_iterator = iter(sub_coupling_structures)
 
-        sub_coupling_structures_iterator = iter(sub_coupling_structures)
-
+        chained_disciplines = []
         for parallel_tasks in self.coupling_structure.sequence:
-            # to parallelize, check if 1 < len(parallel_tasks)
-            # for now, parallel tasks are run sequentially
-            for coupled_disciplines in parallel_tasks:
-                first_disc = coupled_disciplines[0]
-                if len(coupled_disciplines) > 1 or (
-                    len(coupled_disciplines) == 1
-                    and self.coupling_structure.is_self_coupled(first_disc)
-                    and not isinstance(coupled_disciplines[0], MDA)
-                ):
-                    # several disciplines coupled
+            process = self.__create_process_from_disciplines(
+                disciplines,
+                inner_mda_name,
+                inner_mda_options,
+                mdachain_parallel_options,
+                parallel_tasks,
+                mdachain_parallelize_tasks,
+            )
+            chained_disciplines.append(process)
 
-                    # order the MDA disciplines the same way as the
-                    # original disciplines
-                    inner_mda_disciplines = []
-                    for disc in disciplines:
-                        if disc in coupled_disciplines:
-                            inner_mda_disciplines.append(disc)
-
-                    # create a inner-MDA
-                    mda = create_mda(
-                        inner_mda_name,
-                        inner_mda_disciplines,
-                        max_mda_iter=self.max_mda_iter,
-                        tolerance=self.tolerance,
-                        linear_solver_tolerance=self.linear_solver_tolerance,
-                        grammar_type=self.grammar_type,
-                        use_lu_fact=self.use_lu_fact,
-                        linear_solver=self.linear_solver,
-                        linear_solver_options=self.linear_solver_options,
-                        coupling_structure=next(sub_coupling_structures_iterator),
-                        **inner_mda_options,
-                    )
-                    mda.n_processes = self.n_processes
-
-                    chained_disciplines.append(mda)
-                    self.inner_mdas.append(mda)
-                else:
-                    # single discipline
-                    chained_disciplines.append(first_disc)
-
-        # create the MDO chain that sequentially evaluates the inner-MDAs and the
-        # single disciplines
         self.mdo_chain = MDOChain(
             chained_disciplines, name="MDA chain", grammar_type=self.grammar_type
         )
 
+    def __create_process_from_disciplines(
+        self,
+        disciplines: Sequence[MDODiscipline],
+        inner_mda_name: str,
+        inner_mda_options: Mapping[str, str | float | int],
+        mdachain_parallel_options: Mapping[str, str | float | int],
+        parallel_tasks: list[tuple[MDODiscipline]],
+        mdachain_parallelize_tasks: bool,
+    ) -> MDODiscipline:
+        """Create a process from disciplines.
+
+        This method creates a process that will be appended to the main inner
+        :class:`.MDOChain` of the :class:`.MDAChain`.
+        Depending on the number and type of disciplines provided,
+        as well as the options provided by the user,
+        the process may be a sole discipline,
+        a :class:`.MDA`,
+        a :class:`MDOChain`,
+        or a :class:`MDOParallelChain`.
+
+        Args:
+            disciplines: The disciplines.
+            inner_mda_name: The inner :class:`.MDA` class name.
+            inner_mda_options: The inner :class:`.MDA` options.
+            mdachain_parallel_options: The :class:`MDOParallelChain` options.
+            parallel_tasks: The parallel tasks to be processed.
+            mdachain_parallelize_tasks: Whether to parallelize the parallel tasks,
+                if any.
+
+        Returns:
+            A process.
+        """
+        parallel_disciplines = self.__compute_parallel_disciplines(
+            disciplines,
+            parallel_tasks,
+            inner_mda_name,
+            inner_mda_options,
+        )
+
+        return self.__create_process_from_parallel_disciplines(
+            parallel_disciplines,
+            mdachain_parallelize_tasks,
+            mdachain_parallel_options,
+        )
+
+    def __compute_parallel_disciplines(
+        self,
+        disciplines: Sequence[MDODiscipline],
+        parallel_tasks: list[tuple[MDODiscipline]],
+        inner_mda_name: str,
+        inner_mda_options: dict[str, dict[str, int | float | str]],
+    ) -> Sequence[MDODiscipline | MDA]:
+        """Compute the parallel disciplines.
+
+        This method computes the parallel disciplines,
+        if any.
+        If there is any coupled disciplines in a parallel task,
+        a :class:`.MDA` is created,
+        based on the :class:`.MDA` options provided.
+
+        Args:
+            disciplines: The disciplines.
+            parallel_tasks: The parallel tasks.
+            inner_mda_name: The inner :class:`.MDA` class name.
+            inner_mda_options: The inner :class:`.MDA` options.
+
+        Returns:
+            The parallel disciplines.
+        """
+        parallel_disciplines = []
+        for coupled_disciplines in parallel_tasks:
+            is_one_discipline_self_coupled = self.__is_one_discipline_self_coupled(
+                coupled_disciplines
+            )
+            if len(coupled_disciplines) > 1 or is_one_discipline_self_coupled:
+                discipline = self.__create_inner_mda(
+                    disciplines,
+                    coupled_disciplines,
+                    inner_mda_name,
+                    inner_mda_options,
+                )
+                self.inner_mdas.append(discipline)
+            else:
+                discipline = coupled_disciplines[0]
+
+            parallel_disciplines.append(discipline)
+        return parallel_disciplines
+
+    def __create_process_from_parallel_disciplines(
+        self,
+        parallel_disciplines: Sequence[MDODiscipline],
+        mdachain_parallelize_tasks: bool,
+        mdachain_parallel_options: dict[str, int | float | str] | None,
+    ) -> MDODiscipline | MDOChain | MDOParallelChain:
+        """Create a process from parallel disciplines.
+
+        Depending on the number of disciplines and the options provided,
+        the returned GEMSEO process can be a sole :class:`.MDODiscipline` instance,
+        a :class:`.MDOChain` or a :class:`.MDOParallelChain`.
+
+        Args:
+            parallel_disciplines: The parallel disciplines.
+            mdachain_parallelize_tasks: Whether to parallelize the parallel tasks.
+            mdachain_parallel_options: The options of the :class:`.MDOParallelChain`.
+
+        Returns:
+            A GEMSEO process instance.
+        """
+        if len(parallel_disciplines) > 1:
+            process = self.__create_sequential_or_parallel_chain(
+                parallel_disciplines,
+                mdachain_parallelize_tasks,
+                mdachain_parallel_options,
+            )
+        else:
+            process = parallel_disciplines[0]
+        return process
+
+    def __create_inner_mda(
+        self,
+        disciplines: Sequence[MDODiscipline],
+        coupled_disciplines: Sequence[MDODiscipline],
+        inner_mda_name: str,
+        inner_mda_options: dict[str, dict[str, int | float | str]],
+    ) -> MDA:
+        """Create an inner MDA from the coupled disciplines and the MDA options.
+
+        Args:
+            disciplines: The disciplines.
+            coupled_disciplines: The coupled disciplines.
+            inner_mda_name: The inner :class:`.MDA` class name.
+            inner_mda_options: The inner :class:`.MDA` options.
+
+        Returns:
+            The :class:`.MDA` instance.
+        """
+        inner_mda_disciplines = self.__get_coupled_disciplines_initial_order(
+            coupled_disciplines, disciplines
+        )
+        mda = create_mda(
+            inner_mda_name,
+            inner_mda_disciplines,
+            max_mda_iter=self.max_mda_iter,
+            tolerance=self.tolerance,
+            linear_solver_tolerance=self.linear_solver_tolerance,
+            grammar_type=self.grammar_type,
+            use_lu_fact=self.use_lu_fact,
+            linear_solver=self.linear_solver,
+            linear_solver_options=self.linear_solver_options,
+            coupling_structure=next(self.__sub_coupling_structures_iterator),
+            **inner_mda_options,
+        )
+        mda.n_processes = self.n_processes
+        return mda
+
+    def __is_one_discipline_self_coupled(
+        self, disciplines: Sequence[MDODiscipline]
+    ) -> bool:
+        """Whether the disciplines contain only one self-coupled discipline which is also
+        not a MDA.
+
+        Args:
+            disciplines: The disciplines.
+
+        Returns:
+            True if the sole discipline of coupled_disciplines is self-coupled
+            and not a MDA.
+        """
+        first_discipline = disciplines[0]
+        is_one_discipline_self_coupled = (
+            len(disciplines) == 1
+            and self.coupling_structure.is_self_coupled(first_discipline)
+            and not isinstance(disciplines[0], MDA)
+        )
+        return is_one_discipline_self_coupled
+
+    @staticmethod
+    def __get_coupled_disciplines_initial_order(
+        coupled_disciplines: Sequence[MDODiscipline],
+        disciplines: Sequence[MDODiscipline],
+    ) -> list[MDODiscipline]:
+        """Get the coupled disciplines in the same order as initially given by the user.
+
+        Args:
+            coupled_disciplines: The coupled disciplines.
+            disciplines: The disciplines.
+
+        Returns:
+            The ordered list of coupled disciplines.
+        """
+        return [disc for disc in disciplines if disc in coupled_disciplines]
+
+    def __create_sequential_or_parallel_chain(
+        self,
+        parallel_disciplines: Sequence[MDODiscipline],
+        mdachain_parallelize_tasks: bool,
+        mdachain_parallel_options: dict[str, int | float | str] | None,
+    ) -> MDOChain | MDOParallelChain:
+        """Create a :class:`.MDOChain' or :class:`.MDOParallelChain`.
+
+        Args:
+            parallel_disciplines: The parallel disciplines.
+            mdachain_parallelize_tasks: Whether to parallelize the parallel tasks,
+                if any.
+            mdachain_parallel_options: The :class:`MDOParallelChain options.
+
+        Returns:
+            Either a :class:`.MDOChain` or :class:`.MDOParallelChain instance.
+        """
+        if mdachain_parallelize_tasks:
+            process = self.__create_mdo_parallel_chain(
+                parallel_disciplines,
+                mdachain_parallel_options,
+            )
+        else:
+            process = MDOChain(parallel_disciplines, grammar_type=self.grammar_type)
+        return process
+
+    def __create_mdo_parallel_chain(
+        self,
+        parallel_disciplines: Sequence[MDODiscipline],
+        mdachain_parallel_options: dict[str, int | float | str] | None,
+    ) -> MDOParallelChain:
+        """Create a :class:`.MDOParallelChain` with the provided disciplines and options.
+
+        Args:
+            parallel_disciplines: The parallel disciplines.
+            mdachain_parallel_options: The :class:`.MDOParallelChain` options.
+
+        Returns:
+            A :class:`.MDOParallelChain` instance.
+        """
+        if mdachain_parallel_options is None:
+            mdachain_parallel_options = {}
+        return MDOParallelChain(
+            parallel_disciplines,
+            grammar_type=self.grammar_type,
+            **mdachain_parallel_options,
+        )
+
     def _initialize_grammars(self) -> None:
         """Define all inputs and outputs of the chain."""
         if self.mdo_chain is None:  # First call by super class must be ignored.
@@ -275,7 +499,7 @@ class MDAChain(MDA):
     def add_differentiated_outputs(
         self,
         outputs: Iterable[str] | None = None,
-    ) -> None:
+    ) -> None:  # noqa: D102
         MDA.add_differentiated_outputs(self, outputs=outputs)
         if self._chain_linearize:
             self.mdo_chain.add_differentiated_outputs(outputs)
