@@ -90,12 +90,11 @@ generated/sklearn.neighbors.KNeighborsClassifier.html>`_.
 """
 from __future__ import annotations
 
-import logging
 from typing import ClassVar
 from typing import Iterable
-from typing import Mapping
 
 from numpy import ndarray
+from numpy import newaxis
 from numpy import stack
 from sklearn.neighbors import KNeighborsClassifier
 
@@ -104,8 +103,6 @@ from gemseo.mlearning.classification.classification import MLClassificationAlgo
 from gemseo.mlearning.core.ml_algo import TransformerType
 from gemseo.utils.python_compatibility import Final
 
-LOGGER = logging.getLogger(__name__)
-
 
 class KNNClassifier(MLClassificationAlgo):
     """The k-nearest neighbors classification algorithm."""
@@ -116,7 +113,7 @@ class KNNClassifier(MLClassificationAlgo):
     def __init__(
         self,
         data: Dataset,
-        transformer: Mapping[str, TransformerType] | None = None,
+        transformer: TransformerType = MLClassificationAlgo.IDENTITY,
         input_names: Iterable[str] | None = None,
         output_names: Iterable[str] | None = None,
         n_neighbors: int = 5,
@@ -151,7 +148,7 @@ class KNNClassifier(MLClassificationAlgo):
     ) -> ndarray:
         output_data = self.algo.predict(input_data).astype(int)
         if len(output_data.shape) == 1:
-            output_data = output_data[:, None]
+            output_data = output_data[:, newaxis]
         return output_data
 
     def _predict_proba_soft(
