@@ -30,12 +30,11 @@ generated/sklearn.ensemble.RandomForestClassifier.html>`_.
 """
 from __future__ import annotations
 
-import logging
 from typing import ClassVar
 from typing import Iterable
-from typing import Mapping
 
 from numpy import ndarray
+from numpy import newaxis
 from numpy import stack
 from sklearn.ensemble import RandomForestClassifier as SKLRandForest
 
@@ -44,8 +43,6 @@ from gemseo.mlearning.classification.classification import MLClassificationAlgo
 from gemseo.mlearning.core.ml_algo import TransformerType
 from gemseo.utils.python_compatibility import Final
 
-LOGGER = logging.getLogger(__name__)
-
 
 class RandomForestClassifier(MLClassificationAlgo):
     """The random forest classification algorithm."""
@@ -56,7 +53,7 @@ class RandomForestClassifier(MLClassificationAlgo):
     def __init__(
         self,
         data: Dataset,
-        transformer: Mapping[str, TransformerType] | None = None,
+        transformer: TransformerType = MLClassificationAlgo.IDENTITY,
         input_names: Iterable[str] | None = None,
         output_names: Iterable[str] | None = None,
         n_estimators: int = 100,
@@ -91,7 +88,7 @@ class RandomForestClassifier(MLClassificationAlgo):
     ) -> ndarray:
         output_data = self.algo.predict(input_data).astype(int)
         if len(output_data.shape) == 1:
-            output_data = output_data[:, None]
+            output_data = output_data[:, newaxis]
         return output_data
 
     def _predict_proba_soft(
@@ -100,7 +97,7 @@ class RandomForestClassifier(MLClassificationAlgo):
     ) -> ndarray:
         probas = self.algo.predict_proba(input_data)
         if len(probas[0].shape) == 1:
-            probas = probas[..., None]
+            probas = probas[..., newaxis]
         else:
             probas = stack(probas, axis=-1)
         return probas
