@@ -32,13 +32,12 @@ generated/sklearn.svm.SVC.html>`_.
 """
 from __future__ import annotations
 
-import logging
 from typing import Callable
 from typing import ClassVar
 from typing import Iterable
-from typing import Mapping
 
 from numpy import ndarray
+from numpy import newaxis
 from sklearn.svm import SVC
 
 from gemseo.core.dataset import Dataset
@@ -46,8 +45,6 @@ from gemseo.mlearning.classification.classification import MLClassificationAlgo
 from gemseo.mlearning.core.ml_algo import TransformerType
 from gemseo.utils.python_compatibility import Final
 
-LOGGER = logging.getLogger(__name__)
-
 
 class SVMClassifier(MLClassificationAlgo):
     """The Support Vector Machine algorithm for classification."""
@@ -58,7 +55,7 @@ class SVMClassifier(MLClassificationAlgo):
     def __init__(
         self,
         data: Dataset,
-        transformer: Mapping[str, TransformerType] | None = None,
+        transformer: TransformerType = MLClassificationAlgo.IDENTITY,
         input_names: Iterable[str] | None = None,
         output_names: Iterable[str] | None = None,
         C=1.0,  # noqa: N803
@@ -66,7 +63,6 @@ class SVMClassifier(MLClassificationAlgo):
         probability: bool = False,
         **parameters: int | float | bool | str | None,
     ) -> None:
-        # noqa: D205,D212,D415
         """
         Args:
             C: The inverse L2 regularization parameter.
@@ -76,7 +72,7 @@ class SVMClassifier(MLClassificationAlgo):
                 or a callable.
             probability: Whether to enable the probability estimates.
                 The algorithm is faster if set to False.
-        """
+        """  # noqa: D205, D212, D415
         super().__init__(
             data,
             transformer=transformer,
@@ -100,7 +96,7 @@ class SVMClassifier(MLClassificationAlgo):
         self,
         input_data: ndarray,
     ) -> ndarray:
-        return self.algo.predict(input_data)[:, None].astype(int)
+        return self.algo.predict(input_data)[:, newaxis].astype(int)
 
     def _predict_proba_soft(
         self,
