@@ -69,10 +69,8 @@ generated/sklearn.mixture.GaussianMixture.html>`_.
 """
 from __future__ import annotations
 
-import logging
 from typing import ClassVar
 from typing import Iterable
-from typing import Mapping
 from typing import NoReturn
 
 from numpy import ndarray
@@ -83,8 +81,6 @@ from gemseo.mlearning.cluster.cluster import MLPredictiveClusteringAlgo
 from gemseo.mlearning.core.ml_algo import TransformerType
 from gemseo.utils.python_compatibility import Final
 
-LOGGER = logging.getLogger(__name__)
-
 
 class GaussianMixture(MLPredictiveClusteringAlgo):
     """The Gaussian mixture clustering algorithm."""
@@ -95,7 +91,7 @@ class GaussianMixture(MLPredictiveClusteringAlgo):
     def __init__(
         self,
         data: Dataset,
-        transformer: Mapping[str, TransformerType] | None = None,
+        transformer: TransformerType = MLPredictiveClusteringAlgo.IDENTITY,
         var_names: Iterable[str] | None = None,
         n_components: int = 5,
         **parameters: int | float | str | bool | None,
