@@ -45,11 +45,13 @@ from typing import NoReturn
 from numpy import delete as npdelete
 from numpy import mean
 from numpy import ndarray
+from numpy import newaxis
 from numpy import repeat
 from sklearn.metrics import mean_squared_error
 from sklearn.metrics import r2_score
 
 from gemseo.mlearning.qual_measure.error_measure import MLErrorMeasure
+from gemseo.mlearning.qual_measure.quality_measure import MeasureType
 from gemseo.mlearning.regression.regression import MLRegressionAlgo
 
 
@@ -61,7 +63,7 @@ class R2Measure(MLErrorMeasure):
     def __init__(
         self,
         algo: MLRegressionAlgo,
-        fit_transformers: bool = False,
+        fit_transformers: bool = MLErrorMeasure._FIT_TRANSFORMERS,
     ) -> None:
         """
         Args:
@@ -74,41 +76,48 @@ class R2Measure(MLErrorMeasure):
         outputs: ndarray,
         predictions: ndarray,
         multioutput: bool = True,
-    ) -> float | ndarray:
-        multioutput = "raw_values" if multioutput else "uniform_average"
-        return r2_score(outputs, predictions, multioutput=multioutput)
+    ) -> MeasureType:
+        return r2_score(
+            outputs,
+            predictions,
+            multioutput=self._GEMSEO_MULTIOUTPUT_TO_SKLEARN_MULTIOUTPUT[multioutput],
+        )
 
     def evaluate_kfolds(
         self,
         n_folds: int = 5,
         samples: list[int] | None = None,
         multioutput: bool = True,
-        randomize: bool = False,
+        randomize: bool = MLErrorMeasure._RANDOMIZE,
         seed: int | None = None,
-    ) -> float | ndarray:
+        as_dict: bool = False,
+    ) -> MeasureType:
         folds, samples = self._compute_folds(samples, n_folds, randomize, seed)
 
         input_data = self.algo.input_data
         output_data = self.algo.output_data
 
-        multiout = "raw_values" if multioutput else "uniform_average"
-
+        _multioutput = self._GEMSEO_MULTIOUTPUT_TO_SKLEARN_MULTIOUTPUT[multioutput]
         algo = deepcopy(self.algo)
 
         sse = 0
-        ymean = repeat(mean(output_data, axis=0)[None, :], len(output_data), axis=0)
-        var = mean_squared_error(output_data, ymean, multioutput=multiout)
+        ymean = repeat(mean(output_data, axis=0)[newaxis, :], len(output_data), axis=0)
+        var = mean_squared_error(output_data, ymean, multioutput=_multioutput)
         for n_fold in range(n_folds):
             fold = folds[n_fold]
             algo.learn(
                 samples=npdelete(samples, fold), fit_transformers=self._fit_transformers
             )
             mse = mean_squared_error(
-                output_data[fold], algo.predict(input_data[fold]), multioutput=multiout
+                output_data[fold],
+                algo.predict(input_data[fold]),
+                multioutput=_multioutput,
             )
             sse += mse * len(fold)
 
-        return 1 - sse / var / len(ymean)
+        return self._post_process_measure(
+            1 - sse / var / len(ymean), multioutput, as_dict
+        )
 
     def evaluate_bootstrap(
         self,
@@ -116,5 +125,6 @@ class R2Measure(MLErrorMeasure):
         samples: list[int] | None = None,
         multioutput: bool = True,
         seed: int | None = None,
+        as_dict: bool = False,
     ) -> NoReturn:
         raise NotImplementedError
