@@ -19,20 +19,16 @@
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
 """A factory to create regression models.
 
-This module contains a factory to instantiate a :class:`.MLRegressionAlgo` from its
-class name. It also provides the available regression models and allows testing if a
-regression model type is available.
+This module contains a factory to instantiate a :class:`.MLRegressionAlgo` from its class
+name. It also provides the available regression models and allows testing if a regression
+model type is available.
 """
 from __future__ import annotations
 
-import logging
-
 from gemseo.core.factory import Factory
 from gemseo.mlearning.core.factory import MLAlgoFactory
 from gemseo.mlearning.regression.regression import MLRegressionAlgo
 
-LOGGER = logging.getLogger(__name__)
-
 
 class RegressionModelFactory(MLAlgoFactory):
     """This factory instantiates a :class:`.MLRegressionAlgo` from its class name.
