@@ -97,7 +97,6 @@ generated/sklearn.gaussian_process.GaussianProcessRegressor.html>`_.
 """
 from __future__ import annotations
 
-import logging
 from typing import Callable
 from typing import ClassVar
 from typing import Iterable
@@ -107,6 +106,7 @@ from typing import Tuple
 import sklearn.gaussian_process
 from numpy import atleast_2d
 from numpy import ndarray
+from numpy import newaxis
 from numpy import repeat
 from sklearn.gaussian_process.kernels import Kernel
 
@@ -117,8 +117,6 @@ from gemseo.mlearning.regression.regression import MLRegressionAlgo
 from gemseo.utils.data_conversion import concatenate_dict_of_arrays_to_array
 from gemseo.utils.python_compatibility import Final
 
-LOGGER = logging.getLogger(__name__)
-
 __Bounds = Tuple[float, float]
 
 
@@ -132,7 +130,7 @@ class GaussianProcessRegressor(MLRegressionAlgo):
     def __init__(
         self,
         data: Dataset,
-        transformer: Mapping[str, TransformerType] | None = None,
+        transformer: TransformerType = MLRegressionAlgo.IDENTITY,
         input_names: Iterable[str] | None = None,
         output_names: Iterable[str] | None = None,
         kernel: Kernel | None = None,
@@ -179,9 +177,7 @@ class GaussianProcessRegressor(MLRegressionAlgo):
             )
 
         self.algo = sklearn.gaussian_process.GaussianProcessRegressor(
-            normalize_y=False,
             kernel=kernel,
-            copy_X_train=True,
             alpha=alpha,
             optimizer=optimizer,
             n_restarts_optimizer=n_restarts_optimizer,
@@ -240,7 +236,7 @@ class GaussianProcessRegressor(MLRegressionAlgo):
     ) -> ndarray:
         output_data = self.algo.predict(input_data)
         if output_data.ndim == 1:
-            output_data = output_data[:, None]
+            output_data = output_data[:, newaxis]
         return output_data
 
     def predict_std(
@@ -282,5 +278,7 @@ class GaussianProcessRegressor(MLRegressionAlgo):
 
         output_data = self.algo.predict(input_data, return_std=True)[1]
         if output_data.ndim == 1:
-            output_data = repeat(output_data[:, None], self._reduced_dimensions[1], 1)
+            output_data = repeat(
+                output_data[:, newaxis], self._reduced_dimensions[1], 1
+            )
         return output_data
