@@ -62,12 +62,12 @@ from typing import ClassVar
 from typing import Dict
 from typing import Iterable
 from typing import List
-from typing import Mapping
 from typing import NoReturn
 from typing import Optional
 from typing import Union
 
 from numpy import ndarray
+from numpy import newaxis
 from numpy import nonzero
 from numpy import unique
 from numpy import where
@@ -168,7 +168,7 @@ class MOERegressor(MLRegressionAlgo):
     def __init__(
         self,
         data: Dataset,
-        transformer: Mapping[str, TransformerType] | None = None,
+        transformer: TransformerType = MLRegressionAlgo.IDENTITY,
         input_names: Iterable[str] | None = None,
         output_names: Iterable[str] | None = None,
         hard: bool = True,
@@ -527,7 +527,7 @@ class MOERegressor(MLRegressionAlgo):
     ) -> None:
         """Train the clustering algorithm.
 
-        The methods adds resulting labels as a new output in the dataset.
+        The method adds resulting labels as a new output in the dataset.
 
         Args:
             dataset: The dataset containing input and output data.
@@ -551,7 +551,7 @@ class MOERegressor(MLRegressionAlgo):
             with MultiLineString.offset():
                 LOGGER.info("%s", self.clusterer)
 
-        labels = self.clusterer.labels[:, None]
+        labels = self.clusterer.labels[:, newaxis]
         dataset.add_variable(self.LABELS, labels, self.LABELS, False)
 
     def _fit_classifier(
