@@ -12,5 +12,5 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-"""Optimization and DOE history post processing and analysis."""
+"""Optimization and DOE history post-processing and analysis."""
 from __future__ import annotations
