@@ -12,5 +12,5 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-"""|g| optimization history post processing."""
+"""|g| optimization history post-processing."""
 from __future__ import annotations
