@@ -54,6 +54,7 @@ from numpy import dot
 from numpy import eye
 from numpy import inf
 from numpy import ndarray
+from numpy import newaxis
 from numpy import sqrt
 from numpy import trace
 from numpy import zeros
@@ -75,41 +76,38 @@ class HessianApproximation(metaclass=GoogleDocstringInheritanceMeta):
     r"""Approximation of the Hessian matrix from an optimization history."""
 
     history: Database
-    """The optimization history
-    containing input values, output values and Jacobian values.
-    """
+    """The optimization history containing input values, output values and Jacobian
+    values."""
 
     x_ref: ndarray | None
-    """The value :math:`x_K`
-    of the input variables :math:`x`
-    at the iteration :math:`K` of the optimization history;
-    this is the point at which
-    the Hessian matrix and its inverse are approximated."""
+    """The value :math:`x_K` of the input variables :math:`x` at the iteration :math:`K`
+    of the optimization history; this is the point at which the Hessian matrix and its
+    inverse are approximated."""
 
     fgrad_ref: ndarray | None
-    """The value :math:`g_K`
-    of the gradient function :math:`g` of :math:`f` at :math:`x_K`."""
+    """The value :math:`g_K` of the gradient function :math:`g` of :math:`f` at
+    :math:`x_K`."""
 
     f_ref: ndarray | None
     """The value :math:`y_K` of the output of :math:`f` at :math:`x_K`."""
 
     b_mat_history: list[ndarray]
-    r"""The history :math:`B_0,B_1,\ldots,B_K`
-    of the approximations of the Hessian matrix :math:`B`."""
+    r"""The history :math:`B_0,B_1,\ldots,B_K` of the approximations of the Hessian
+    matrix :math:`B`."""
 
     h_mat_history: list[ndarray]
-    r"""The history :math:`H_0,H_1,\ldots,H_K`
-    of the approximations of the inverse Hessian matrix :math:`H`."""
+    r"""The history :math:`H_0,H_1,\ldots,H_K` of the approximations of the inverse
+    Hessian matrix :math:`H`."""
 
     def __init__(
         self,
         history: Database,
-    ) -> None:  # noqa: E262, E261
+    ) -> None:
         """
         Args:
             history: The optimization history
                 containing input values, output values and Jacobian values.
-        """
+        """  # noqa: D205, D212, D415
         self.history = history
         self.x_ref = None
         self.fgrad_ref = None
@@ -172,13 +170,14 @@ class HessianApproximation(metaclass=GoogleDocstringInheritanceMeta):
 
         if grad_hist_length < 2:
             raise ValueError(
-                "Cannot build approximation for function: {} "
-                "because its gradient history is too small : {}.".format(
-                    funcname, grad_hist_length
-                )
+                f"Cannot build approximation for function: {funcname} "
+                f"because its gradient history is too small: {grad_hist_length}."
             )
 
         grad_hist = array(grad_hist)
+        if grad_hist.ndim == 1:
+            grad_hist = grad_hist[:, newaxis]
+
         x_hist = array(x_hist)
         if x_hist.shape != (grad_hist.shape[0], grad_hist.shape[-1]):
             # TODO: add shapes in the exception message
@@ -188,21 +187,22 @@ class HessianApproximation(metaclass=GoogleDocstringInheritanceMeta):
 
         # Function is a vector, Jacobian is a 2D matrix
         if grad_hist.ndim == 3:
-            if func_index is None:
-                raise ValueError(
-                    "Function {} has a vector output "
-                    "then function index of output "
-                    "must be specified.".format(funcname)
-                )
+            if grad_hist.shape[1] == 1:
+                func_index = 0
+            else:
+                if func_index is None:
+                    raise ValueError(
+                        f"Function {funcname} has a vector output, "
+                        "the function index of the output must be specified."
+                    )
 
-            output_size = grad_hist.shape[1]
-            if not 0 <= func_index < output_size:
-                raise ValueError(
-                    "Function {} has a vector output of size {}, "
-                    "function index {} is out of range.".format(
-                        funcname, output_size, func_index
+                output_size = grad_hist.shape[1]
+                if not 0 <= func_index < output_size:
+                    raise ValueError(
+                        f"Function {funcname} has a vector output "
+                        f"of size {output_size}, "
+                        f"function index {func_index} is out of range."
                     )
-                )
 
             grad_hist = grad_hist[:, func_index, :]
 
@@ -223,7 +223,7 @@ class HessianApproximation(metaclass=GoogleDocstringInheritanceMeta):
             # TODO: split into two tests
             raise ValueError(
                 "Insufficient optimization history size, "
-                "niter={} nparam = {}.".format(n_iterations, input_dimension)
+                f"niter={n_iterations} nparam={input_dimension}."
             )
 
         self.x_ref = x_hist[-1]
@@ -298,8 +298,8 @@ class HessianApproximation(metaclass=GoogleDocstringInheritanceMeta):
         n_iterations = x_grad_hist.shape[0]
         if iteration >= n_iterations:
             raise ValueError(
-                "Iteration {} is higher than number of gradients "
-                "in the database : {}.".format(iteration, n_iterations)
+                f"Iteration {iteration} is higher than the number of gradients "
+                f"in the database: {n_iterations}."
             )
 
         input_diff = atleast_2d(x_hist[iteration + 1] - x_hist[iteration]).T
@@ -611,9 +611,9 @@ class HessianApproximation(metaclass=GoogleDocstringInheritanceMeta):
         count = 0
         k = 0
         for s_k, y_k in self.iterate_s_k_y_k(x_hist, grad_hist):
-            k = k + 1
+            k += 1
             if dot(s_k.T, y_k) > angle_tol and norm(y_k, inf) < step_tol:
-                count = count + 1
+                count += 1
                 self.iterate_inverse_approximation(
                     h_mat,
                     s_k,
@@ -789,7 +789,7 @@ class BFGSApprox(HessianApproximation):
     """Hessian matrix approximation with the BFGS algorithm."""
 
     @staticmethod
-    def iterate_s_k_y_k(
+    def iterate_s_k_y_k(  # noqa:D102
         x_hist: ndarray,
         x_grad_hist: ndarray,
     ) -> Generator[tuple[ndarray, ndarray]]:
@@ -826,7 +826,7 @@ class SR1Approx(HessianApproximation):
     EPSILON = 1e-8
 
     @staticmethod
-    def iterate_approximation(
+    def iterate_approximation(  # noqa:D102
         b_mat: ndarray,
         s_k: ndarray,
         y_k: ndarray,
@@ -844,9 +844,9 @@ class SR1Approx(HessianApproximation):
 
 
 class LSTSQApprox(HessianApproximation):
-    """Least squares approximation of an Hessian matrix from an optimization history."""
+    """Least squares approximation of a Hessian matrix from an optimization history."""
 
-    def build_approximation(
+    def build_approximation(  # noqa:D102
         self,
         funcname: str,
         save_diag: bool = False,
