@@ -17,7 +17,7 @@
 #                           documentation
 #        :author: Matthias De Lozzo
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
-r"""Draw a bar plot from a :class:`.Dataset`. """
+r"""Draw a bar plot from a :class:`.Dataset`."""
 from __future__ import annotations
 
 import matplotlib.pyplot as plt
@@ -41,7 +41,7 @@ class BarPlot(DatasetPlot):
         """
         Args:
             n_digits: The number of digits to print the different bar values.
-        """
+        """  # noqa: D205, D212, D415
         super().__init__(dataset, n_digits=n_digits)
 
     def _plot(
@@ -50,7 +50,7 @@ class BarPlot(DatasetPlot):
         axes: None | Axes = None,
     ) -> list[Figure]:
         # radar solid grid lines
-        all_data, _, sizes = self.dataset.get_all_data(False, False)
+        all_data, _, sizes = self.dataset.get_all_data(False)
         variables_names = self.dataset.columns_names
         dimension = sum(sizes.values())
         series_names = self.dataset.row_names
@@ -104,4 +104,6 @@ class BarPlot(DatasetPlot):
         axes.set_ylabel(self.ylabel)
         axes.set_title(self.title, fontsize=self.font_size * 1.2)
         axes.legend(fontsize=self.font_size)
+        axes.set_axisbelow(True)
+        axes.grid()
         return [fig]
