@@ -49,7 +49,6 @@ import matplotlib.pyplot as plt
 from matplotlib.lines import Line2D
 from numpy import array
 from numpy import atleast_3d
-from numpy import bool as np_bool
 from numpy import median
 from numpy import poly1d
 from numpy import polyfit
@@ -67,7 +66,6 @@ POSTSTUDY_DIRECTORY = POST_DIRECTORY / "scalability_study"
 
 
 class PostScalabilityStudy:
-
     """The PostScalabilityStudy class aims to post-process a list of scalability results
     stored in a directory."""
 
@@ -339,7 +337,7 @@ class PostScalabilityStudy:
         :param list(str) xticks_labels: list of xticks labels (default: None)
         :param float xmargin: margin on left and right sides of the x-axis
         :param int minbox: minimal number of values for boxplot (default: 2).
-        :param bool notch: if True, will produced a notched boxplot.
+        :param bool notch: if True, will produce a notched boxplot.
         :param float whis:  the reach of the whiskers to the beyond
             the first and third quartiles (default: 1.5).
         """
@@ -407,7 +405,7 @@ class PostScalabilityStudy:
         :param list(str) labels: list of xticks labels (default: None)
         :param list(str) scales: scales
         :param str color: line color.
-        :param bool notch: if True, will produced a notched boxplot.
+        :param bool notch: if True, will produce a notched boxplot.
         :param float whis:  the reach of the whiskers to the beyond
             the first and third quartiles (default: 1.5).
         :param float xmargin: margin on left and right sides of the x-axis
@@ -445,7 +443,7 @@ class PostScalabilityStudy:
         :param list(float) xticks: values of xticks
         :param str edge_color: edge color
         :param str fill_color: fill color
-        :param bool notch: if True, will produced a notched boxplot.
+        :param bool notch: if True, will produce a notched boxplot.
         :param list(float) widths: widths of boxplots
         :param float whis:  the reach of the whiskers to the beyond
             the first and third quartiles
@@ -453,7 +451,7 @@ class PostScalabilityStudy:
         if len(data.shape) == 3:
             data = data[0, :, :]
 
-        if data.dtype == np_bool:
+        if data.dtype == bool:
             # To prevent error when arrays are substracted with recent numpy
             data = data.astype(int)
 
