@@ -43,12 +43,11 @@ LOGGER = logging.getLogger(__name__)
 
 
 class TMProblem:
-
     """The scalable problem from Tedford and Martins, 2010, builds a list of strongly
     coupled models (:class:`.TMSubModel`) completed by a main model
     (:class:`.TMMainModel`) computing the objective function and the constraints.
 
-    These disciplines are defined on an unit design space whose parameters comprised in
+    These disciplines are defined on a unit design space whose parameters comprised in
     [0, 1] (:class:`.TMDesignSpace`). This problem is defined by the number of shared
     design parameters, the number of local design parameters per discipline and the
     number of output coupling variables per discipline. The strongly coupled disciplines
@@ -78,7 +77,7 @@ class TMProblem:
             use circular coupling. Default: True.
         :param bool noised_coupling: if True, add a noise component u_local_i
             on the i-th discipline output.
-        :param int seed: seed for replicability.
+        :param int seed: seed for reproducibility.
         """
         npseed(seed)
         self._seed = seed
