@@ -49,7 +49,7 @@ class OTNormalDistribution(OTDistribution):
         upper_bound: float | None = None,
         threshold: float = 0.5,
     ) -> None:
-        """.. # noqa: D205,D212,D415
+        """
         Args:
             variable: The name of the normal random variable.
             mu: The mean of the normal random variable.
@@ -64,7 +64,7 @@ class OTNormalDistribution(OTDistribution):
             upper_bound: An upper bound to truncate the distribution.
                 If None, no upper truncation.
             threshold: A threshold in [0,1].
-        """
+        """  # noqa: D205,D212,D415
         standard_parameters = {self._MU: mu, self._SIGMA: sigma}
         super().__init__(
             variable,
