@@ -50,7 +50,7 @@ class OTTriangularDistribution(OTDistribution):
         upper_bound: float | None = None,
         threshold: float = 0.5,
     ) -> None:
-        """.. # noqa: D205,D212,D415
+        """
         Args:
             variable: The name of the triangular random variable.
             minimum: The minimum of the triangular random variable.
@@ -65,7 +65,7 @@ class OTTriangularDistribution(OTDistribution):
             upper_bound: An upper bound to truncate the distribution.
                 If None, no upper truncation.
             threshold: A threshold in [0,1].
-        """
+        """  # noqa: D205,D212,D415
         standard_parameters = {
             self._LOWER: minimum,
             self._MODE: mode,
