@@ -45,12 +45,12 @@ class SPExponentialDistribution(SPDistribution):
         loc: float = 0.0,
         dimension: int = 1,
     ) -> None:
-        """.. # noqa: D205,D212,D415
+        """
         Args:
             variable: The name of the exponential random variable.
             rate: The rate of the exponential random variable.
             loc: The location of the exponential random variable.
             dimension: The dimension of the exponential random variable.
-        """
+        """  # noqa: D205,D212,D415
         parameters = {"loc": loc, "scale": 1 / float(rate)}
         super().__init__(variable, "expon", parameters, dimension)
