@@ -17,7 +17,7 @@
 #                           documentation
 #        :author: Matthias De Lozzo
 #    OTHER AUTHORS   - MACROSCOPIC CHANGES
-"""Class to create an uniform distribution from the SciPy library.
+"""Class to create a uniform distribution from the SciPy library.
 
 This class inherits from :class:`.SPDistribution`.
 """
@@ -27,7 +27,7 @@ from gemseo.uncertainty.distributions.scipy.distribution import SPDistribution
 
 
 class SPUniformDistribution(SPDistribution):
-    """Create an uniform distribution.
+    """Create a uniform distribution.
 
     Example:
         >>> from gemseo.uncertainty.distributions.scipy.uniform import (
@@ -45,13 +45,13 @@ class SPUniformDistribution(SPDistribution):
         maximum: float = 1.0,
         dimension: int = 1,
     ) -> None:
-        """.. # noqa: D205,D212,D415
+        """
         Args:
             variable: The name of the uniform random variable.
             minimum: The minimum of the uniform random variable.
             maximum: The maximum of the uniform random variable.
             dimension: The dimension of the uniform random variable.
-        """
+        """  # noqa: D205,D212,D415
         parameters = {"loc": minimum, "scale": maximum - minimum}
         standard_parameters = {self._LOWER: minimum, self._UPPER: maximum}
         super().__init__(
