@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com
 #
 # This program is free software; you can redistribute it and/or
@@ -13,7 +12,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
 """Capabilities to run a sensitivity analysis.
 
 This package contains:
@@ -28,3 +26,4 @@ This package contains:
   - :class:`.MorrisAnalysis`,
   - :class:`.SobolAnalysis` (based on OpenTURNS capabilities),
 """
+from __future__ import annotations
