@@ -30,14 +30,9 @@ from typing import Mapping
 from typing import Sequence
 
 from numpy import array
+from numpy import newaxis
 from numpy import vstack
-from openturns import CorrelationAnalysis_PCC
-from openturns import CorrelationAnalysis_PearsonCorrelation
-from openturns import CorrelationAnalysis_PRCC
-from openturns import CorrelationAnalysis_SignedSRC
-from openturns import CorrelationAnalysis_SpearmanCorrelation
-from openturns import CorrelationAnalysis_SRC
-from openturns import CorrelationAnalysis_SRRC
+from numpy.typing import NDArray
 from openturns import Sample
 
 from gemseo.algos.doe.doe_lib import DOELibraryOptionType
@@ -48,7 +43,16 @@ from gemseo.post.dataset.radar_chart import RadarChart
 from gemseo.uncertainty.sensitivity.analysis import IndicesType
 from gemseo.uncertainty.sensitivity.analysis import OutputsType
 from gemseo.uncertainty.sensitivity.analysis import SensitivityAnalysis
+from gemseo.utils.compatibility.openturns import compute_pcc
+from gemseo.utils.compatibility.openturns import compute_pearson_correlation
+from gemseo.utils.compatibility.openturns import compute_prcc
+from gemseo.utils.compatibility.openturns import compute_signed_src
+from gemseo.utils.compatibility.openturns import compute_spearman_correlation
+from gemseo.utils.compatibility.openturns import compute_src
+from gemseo.utils.compatibility.openturns import compute_srrc
 from gemseo.utils.data_conversion import split_array_to_dict_of_arrays
+from gemseo.utils.string_tools import pretty_str
+from gemseo.utils.string_tools import repr_variable
 
 LOGGER = logging.getLogger(__name__)
 
@@ -91,13 +95,13 @@ class CorrelationAnalysis(SensitivityAnalysis):
     _SRRC = "srrc"
     _SSRRC = "ssrrc"
     _ALGORITHMS = {
-        _PEARSON: CorrelationAnalysis_PearsonCorrelation,
-        _SPEARMAN: CorrelationAnalysis_SpearmanCorrelation,
-        _PCC: CorrelationAnalysis_PCC,
-        _PRCC: CorrelationAnalysis_PRCC,
-        _SRC: CorrelationAnalysis_SRC,
-        _SRRC: CorrelationAnalysis_SRRC,
-        _SSRRC: CorrelationAnalysis_SignedSRC,
+        _PEARSON: compute_pearson_correlation,
+        _SPEARMAN: compute_spearman_correlation,
+        _PCC: compute_pcc,
+        _PRCC: compute_prcc,
+        _SRC: compute_src,
+        _SRRC: compute_srrc,
+        _SSRRC: compute_signed_src,
     }
     DEFAULT_DRIVER = "OT_MONTE_CARLO"
 
@@ -131,13 +135,12 @@ class CorrelationAnalysis(SensitivityAnalysis):
         name: str,
     ) -> None:
         if name not in self._ALGORITHMS:
-            methods = self._ALGORITHMS.keys()
             raise NotImplementedError(
-                "{} is a bad method name. "
-                "Available ones are {}.".format(name, methods)
+                f"{name} is not an sensitivity method; "
+                f"available ones are {pretty_str(sorted(self._ALGORITHMS.keys()))}."
             )
         else:
-            LOGGER.info("Use {} indices as main indices.")
+            LOGGER.info("Use %s indices as main indices.", name)
             self._main_method = name
 
     def compute_indices(  # noqa: D102
@@ -147,7 +150,7 @@ class CorrelationAnalysis(SensitivityAnalysis):
         if not isinstance(output_names, list):
             output_names = [output_names]
         inputs = Sample(self.dataset.get_data_by_group(self.dataset.INPUT_GROUP))
-        outputs = self.dataset.get_data_by_names(output_names, True)
+        outputs = self.dataset.get_data_by_names(output_names)
         self.__correlation = {}
         for algo_name, algo_value in self._ALGORITHMS.items():
             inputs_names = self.dataset.get_names(self.dataset.INPUT_GROUP)
@@ -156,7 +159,7 @@ class CorrelationAnalysis(SensitivityAnalysis):
             for output_name, value in outputs.items():
                 self.__correlation[algo_name][output_name] = []
                 for index in range(value.shape[1]):
-                    sub_outputs = Sample(value[:, index][:, None])
+                    sub_outputs = Sample(value[:, index][:, newaxis])
                     coefficient = array(algo_value(inputs, sub_outputs))
                     coefficient = split_array_to_dict_of_arrays(
                         coefficient, sizes, inputs_names
@@ -166,7 +169,7 @@ class CorrelationAnalysis(SensitivityAnalysis):
 
     @property
     def pcc(self) -> IndicesType:
-        """dict: The Partial Correlation Coefficients.
+        """The Partial Correlation Coefficients.
 
         With the following structure:
 
@@ -184,7 +187,7 @@ class CorrelationAnalysis(SensitivityAnalysis):
 
     @property
     def prcc(self) -> IndicesType:
-        """dict: The Partial Rank Correlation Coefficients.
+        """The Partial Rank Correlation Coefficients.
 
         With the following structure:
 
@@ -202,7 +205,7 @@ class CorrelationAnalysis(SensitivityAnalysis):
 
     @property
     def src(self) -> IndicesType:
-        """dict: The Standard Regression Coefficients.
+        """The Standard Regression Coefficients.
 
         With the following structure:
 
@@ -220,7 +223,7 @@ class CorrelationAnalysis(SensitivityAnalysis):
 
     @property
     def srrc(self) -> IndicesType:
-        """dict: The Standard Rank Regression Coefficients.
+        """The Standard Rank Regression Coefficients.
 
         With the following structure:
 
@@ -256,7 +259,7 @@ class CorrelationAnalysis(SensitivityAnalysis):
 
     @property
     def pearson(self) -> IndicesType:
-        """dict: The Pearson coefficients.
+        """The Pearson coefficients.
 
         With the following structure:
 
@@ -274,7 +277,7 @@ class CorrelationAnalysis(SensitivityAnalysis):
 
     @property
     def spearman(self) -> IndicesType:
-        """dict: The Spearman coefficients.
+        """The Spearman coefficients.
 
          ith the following structure:
 
@@ -292,7 +295,7 @@ class CorrelationAnalysis(SensitivityAnalysis):
 
     @property
     def indices(self) -> dict[str, IndicesType]:
-        """dict: The sensitivity indices.
+        """The sensitivity indices.
 
         With the following structure:
 
@@ -326,23 +329,35 @@ class CorrelationAnalysis(SensitivityAnalysis):
         file_name: str | None = None,
         file_format: str | None = None,
     ) -> None:
-        if not isinstance(output, tuple):
-            output = (output, 0)
+        if isinstance(output, str):
+            output_name, output_index = output, 0
+        else:
+            output_name, output_index = output
+
+        all_indices = sorted(self._ALGORITHMS)
         dataset = Dataset()
-        inputs_names = self.dataset.get_names(self.dataset.INPUT_GROUP)
-        inputs_names = self._filter_names(inputs_names, inputs)
-        algorithms = sorted(self._ALGORITHMS)
-        data = {name: [] for name in inputs_names}
-        for method in algorithms:
-            indices = getattr(self, method)
-            for name in inputs_names:
-                data[name].append(indices[output[0]][output[1]][name])
-        for name in inputs_names:
-            dataset.add_variable(name, vstack(data[name]))
-        dataset.row_names = algorithms
+        for input_name in self._filter_names(
+            self.dataset.get_names(self.dataset.INPUT_GROUP), inputs
+        ):
+            # Store all the sensitivity indices
+            # related to the tuple (output_name, output_index, input_name)
+            # in a 2D NumPy array shaped as (n_indices, input_dimension).
+            dataset.add_variable(
+                input_name,
+                vstack(
+                    [
+                        getattr(self, indices)[output_name][output_index][input_name]
+                        for indices in all_indices
+                    ]
+                ),
+            )
+
+        dataset.row_names = all_indices
         plot = RadarChart(dataset)
-        output = f"{output[0]}({output[1]})"
-        plot.title = title or f"Correlation indices for the output {output}"
+        output_name = repr_variable(
+            output_name, output_index, size=self.dataset.sizes[output_name]
+        )
+        plot.title = title or f"Correlation indices for the output {output_name}"
         plot.rmin = -1.0
         plot.rmax = 1.0
         file_path = self._file_path_manager.create_file_path(
@@ -389,3 +404,7 @@ class CorrelationAnalysis(SensitivityAnalysis):
             max_radius=max_radius,
             **options,
         )
+
+    @staticmethod
+    def _aggregate_sensitivity_indices(indices: NDArray[float]) -> float:  # noqa: D102
+        return abs(indices).sum()
