@@ -20,7 +20,6 @@
 """Module with a factory to create an instance of :class:`.SensitivityAnalysis`."""
 from __future__ import annotations
 
-import logging
 from typing import Any
 from typing import Collection
 from typing import Iterable
@@ -32,8 +31,6 @@ from gemseo.core.discipline import MDODiscipline
 from gemseo.core.factory import Factory
 from gemseo.uncertainty.sensitivity.analysis import SensitivityAnalysis
 
-LOGGER = logging.getLogger(__name__)
-
 
 class SensitivityAnalysisFactory:
     """Factory to build instances of :class:`.SensitivityAnalysis`.
