@@ -69,7 +69,6 @@ This methodology relies on the :class:`.MorrisAnalysis` class.
 """
 from __future__ import annotations
 
-import logging
 from pathlib import Path
 from typing import Any
 from typing import Collection
@@ -90,8 +89,7 @@ from gemseo.disciplines.utils import get_all_outputs
 from gemseo.uncertainty.sensitivity.analysis import IndicesType
 from gemseo.uncertainty.sensitivity.analysis import SensitivityAnalysis
 from gemseo.uncertainty.sensitivity.morris.oat import _OATSensitivity
-
-LOGGER = logging.getLogger(__name__)
+from gemseo.utils.string_tools import repr_variable
 
 
 class MorrisAnalysis(SensitivityAnalysis):
@@ -130,9 +128,7 @@ class MorrisAnalysis(SensitivityAnalysis):
         ...     "x3", "OTUniformDistribution", minimum=-pi, maximum=pi
         ... )
         >>>
-        >>> analysis = MorrisAnalysis(
-        ...     [discipline], parameter_space, n_samples=None, n_replicates=5
-        ... )
+        >>> analysis = MorrisAnalysis([discipline], parameter_space, n_samples=None)
         >>> indices = analysis.compute_indices()
     """
     mu_: dict[str, dict[str, ndarray]]
@@ -234,7 +230,7 @@ class MorrisAnalysis(SensitivityAnalysis):
         formulation: str = "MDF",
         **formulation_options: Any,
     ) -> None:
-        r""".. # noqa: D205,D212,D415
+        r"""..
         Args:
             n_replicates: The number of times
                 the OAT method is repeated. Used only if ``n_samples`` is None.
@@ -245,7 +241,7 @@ class MorrisAnalysis(SensitivityAnalysis):
 
         Raises:
             ValueError: If at least one input dimension is not equal to 1.
-        """
+        """  # noqa: D205, D212, D415
         if parameter_space.dimension != len(parameter_space.variables_names):
             raise ValueError("Each input dimension must be equal to 1.")
 
@@ -300,11 +296,11 @@ class MorrisAnalysis(SensitivityAnalysis):
         outputs: Sequence[str] | None = None,
         normalize: bool = False,
     ) -> dict[str, IndicesType]:
-        """.. # noqa: D205 D212 D415
+        """
         Args:
             normalize: Whether to normalize the indices
                 with the empirical bounds of the outputs.
-        """
+        """  # noqa: D205 D212 D415
         fd_data = self.dataset.get_data_by_group(self.dataset.OUTPUT_GROUP, True)
         output_names = outputs or self.default_output
         if not isinstance(output_names, list):
@@ -389,9 +385,7 @@ class MorrisAnalysis(SensitivityAnalysis):
         lower_mu: float | None = None,
         lower_sigma: float | None = None,
     ) -> None:
-        r""".. # noqa: D415,D417
-
-        Plot the Morris indices for each input variable.
+        r"""Plot the Morris indices for each input variable.
 
         For :math:`i\in\{1,\ldots,d\}`,
         plot :math:`\mu_i^*` in function of :math:`\sigma_i`.
@@ -403,7 +397,7 @@ class MorrisAnalysis(SensitivityAnalysis):
                 If None, use a default value.
             lower_sigma: The lower bound for :math:`\sigma`.
                 If None, use a default value.
-        """
+        """  # noqa: D415 D417
         if not isinstance(output, tuple):
             output = (output, 0)
         names = self.dataset.get_names(self.dataset.INPUT_GROUP)
@@ -414,14 +408,17 @@ class MorrisAnalysis(SensitivityAnalysis):
         ax.scatter(x_val, y_val)
         ax.set_xlabel(r"$\mu^*$")
         ax.set_ylabel(r"$\sigma$")
-        output = f"{output[0]}({output[1]})"
-        default_title = "Sampling: {}(size={}) - Relative step: {} - Output: {}"
-        default_title = default_title.format(
-            self._algo_name, self.__n_replicates, self.__step, output
+        default_title = "Sampling: {}(size={}) - Relative step: {} - Output: {}".format(
+            self._algo_name,
+            self.__n_replicates,
+            self.__step,
+            repr_variable(*output, size=len(self.sigma[output[0]])),
         )
         ax.set_xlim(left=lower_mu)
         ax.set_ylim(bottom=lower_sigma)
         ax.set_title(title or default_title)
+        ax.set_axisbelow(True)
+        ax.grid()
         x_offset = offset * (max(x_val) - min(x_val)) / 100.0
         y_offset = offset * (max(y_val) - min(y_val)) / 100.0
         for index, txt in enumerate(names):
