@@ -21,8 +21,10 @@
 from __future__ import annotations
 
 from numpy import exp
-from numpy import ndarray
 
+from gemseo.uncertainty.statistics.tolerance_interval.distribution import (
+    Bounds,
+)
 from gemseo.uncertainty.statistics.tolerance_interval.distribution import (
     ToleranceIntervalSide,
 )
@@ -48,14 +50,14 @@ class LogNormalToleranceInterval(NormalToleranceInterval):
         std: float,
         location: float,
     ) -> None:
-        """.. # noqa: D205 D212 D415
+        """
         Args:
             mean: The estimation of the mean of the natural logarithm
                 of a log-normal distributed random variable.
             std: The estimation of the standard deviation of the natural logarithm
                 of a log-normal distributed random variable.
             location: The estimation of the location of the log-normal distributed.
-        """
+        """  # noqa: D205 D212 D415
         super().__init__(size, mean, std)
         self.__location = location
 
@@ -64,6 +66,6 @@ class LogNormalToleranceInterval(NormalToleranceInterval):
         coverage: float,
         confidence: float = 0.95,
         side: ToleranceIntervalSide = ToleranceIntervalSide.BOTH,
-    ) -> tuple[ndarray, ndarray]:
+    ) -> Bounds:
         lower, upper = super().compute(coverage, confidence, side)
-        return exp(lower) + self.__location, exp(upper) + self.__location
+        return Bounds(exp(lower) + self.__location, exp(upper) + self.__location)
