@@ -46,12 +46,12 @@ class WeibullToleranceInterval(ToleranceInterval):
         shape: float,
         location: float,
     ) -> None:
-        """.. # noqa: D205 D212 D415
+        """
         Args:
             scale: The estimation of the scale of the Weibull distribution.
             shape: The estimation of the shape of the Weibull distribution.
             location: The estimation of the location of the Weibull distribution.
-        """
+        """  # noqa: D205 D212 D415
         super().__init__(size)
         self.__scale = scale
         self.__shape = shape
