@@ -94,21 +94,19 @@ def parse_rest(
     return parsed_doc
 
 
-# regex pattern for finding the arguments section of a google docstring
+# regex pattern for finding the arguments section of a Google docstring
 # docstring-inheritance replaces the section title "Args" with "Parameters"
 RE_PATTERN_ARGS_SECTION = re.compile(
-    r"(?:Args|Parameters)\s*:\s*\n(.*?)(?:\n\n[^\s]|$)", flags=re.DOTALL
+    r"(?:Args|Parameters)\s*:\s*\n(.*?)(?:\n\n\S|$)", flags=re.DOTALL
 )
 
-# regex pattern for finding the arguments names and description of a google docstring
+# regex pattern for finding the arguments names and description of a Google docstring
 RE_PATTERN_ARGS = re.compile(
     r"\**(\w+)\s*:\s*(.*?)(?:$|(?=\n\**\w+\s*:))", flags=re.DOTALL
 )
 
 
-def parse_google(
-    docstring: str,
-) -> dict[str, str]:
+def parse_google(docstring: str) -> dict[str, str]:
     """Parse a Google docstring.
 
     Args:
@@ -120,7 +118,7 @@ def parse_google(
     args_sections = RE_PATTERN_ARGS_SECTION.findall(docstring)
 
     if len(args_sections) != 1:
-        # This is not a google docstring
+        # This is not a Google docstring
         return {}
 
     # remove leading common blank spaces
@@ -129,7 +127,9 @@ def parse_google(
     parsed_doc = {}
 
     for name, desc in RE_PATTERN_ARGS.findall(args_section):
-        # remove multiple blank spaces and carriage returns
-        parsed_doc[name] = re.sub(r"\s+", " ", desc).strip()
+        # remove multiple blank spaces
+        parsed_doc[name] = re.sub(
+            r"\n ", "\n", re.sub(r"[\r\t\f\v ]+", " ", desc).strip()
+        )
 
     return parsed_doc
