@@ -204,7 +204,7 @@ class XDSMizer:
         """Generate a XDSM diagram from the process.
 
         By default,
-        a self contained HTML file is generated,
+        a self-contained HTML file is generated,
         that can be viewed in a browser.
 
         Args:
@@ -245,7 +245,7 @@ class XDSMizer:
 
         if html_output or open_browser:
             if no_html_loc:
-                output_directory_path = Path(mkdtemp(suffix="", prefix="tmp", dir=None))
+                output_directory_path = Path(mkdtemp(suffix="", prefix="tmp"))
             out_file_path = (output_directory_path / outfile_basename).with_suffix(
                 ".html"
             )
@@ -350,7 +350,6 @@ class XDSMizer:
                         atom.status
                         and atom.parent.status is MDODiscipline.STATUS_RUNNING
                     ):
-
                         node = None
                         for a_node in nodes:
                             if a_node["id"] == self.to_id[atom]:
@@ -603,7 +602,10 @@ def expand(
     elif isinstance(wks, ParallelExecSequence):
         res = []
         for sequence in wks.sequences:
-            res += expand(sequence, to_id)
+            if isinstance(sequence, AtomicExecSequence):
+                res += expand(sequence, to_id)
+            else:
+                res.append(expand(sequence, to_id))
         ids = [{"parallel": res}]
     elif isinstance(wks, LoopExecSequence):
         if (
