@@ -47,6 +47,7 @@ import numpy as np
 
 from gemseo.core.discipline import MDODiscipline
 from gemseo.wrappers.matlab.engine import get_matlab_engine
+from gemseo.wrappers.matlab.engine import MatlabEngine
 from gemseo.wrappers.matlab.matlab_data_processor import convert_array_from_matlab
 from gemseo.wrappers.matlab.matlab_data_processor import double2array
 from gemseo.wrappers.matlab.matlab_data_processor import load_matlab_file
@@ -114,13 +115,12 @@ class MatlabDiscipline(MDODiscipline):
         cache_file_path: str | None = None,
         is_jac_returned_by_func: bool = False,
     ) -> None:
-        # noqa: D205,D212,D415
         """
         Args:
             matlab_fct: The path of the Matlab file or Name of the function.
             input_names: The list of input variables.
             output_names: The list of output variables.
-            add_subfold_path: If True, add all sub-folder to matlab engine path..
+            add_subfold_path: If True, add all sub-folder to matlab engine path.
             search_file: The root directory to launch the research of matlab file.
             matlab_engine_name: The name of the singleton used for this discipline.
             matlab_data_file: The .mat file or path containing default values of data.
@@ -149,7 +149,7 @@ class MatlabDiscipline(MDODiscipline):
                 Default is False.
                 If True, the conventional name 'jac_dout_din' is used as jacobian
                 term of any output 'out' with respect to input 'in'.
-        """
+        """  # noqa: D205, D212, D415
         super().__init__(
             name=name,
             input_grammar_file=input_grammar_file,
@@ -215,6 +215,15 @@ class MatlabDiscipline(MDODiscipline):
         if self.__is_jac_returned_by_func:
             self.__reorder_and_check_jacobian_consistency()
 
+    @property
+    def engine(self) -> MatlabEngine:
+        """The matlab engine of the discipline.
+
+        The engine is associated to the ``matlab_engine_name`` provided at the instance
+        construction.
+        """
+        return self.__engine
+
     @property
     def function_name(self) -> str:
         """Return the name of the function."""
@@ -245,7 +254,7 @@ class MatlabDiscipline(MDODiscipline):
         re_matfile = re.compile(r"\S+\.\S*")
         grps = re_matfile.search(file_name)
         if grps is None:
-            file_name = file_name + extension
+            file_name += extension
 
         file_path = ""
         for subdir, _, files in os.walk(str(root_dir)):
@@ -341,7 +350,7 @@ class MatlabDiscipline(MDODiscipline):
         self.output_grammar.update_from_data(output_data)
 
         # If none input matlab data is prescribed, we cannot know
-        # the size of inputs and outputs. Thus we must evaluate
+        # the size of inputs and outputs. Thus, we must evaluate
         # the function in order to know the sizes
         if matlab_data_file is not None:
             self.__is_size_known = True
