@@ -17,11 +17,13 @@
 #                           documentation
 #        :author: Benoit Pauwels
 """Build matrices from linear constraints for solvers."""
+from __future__ import annotations
+
 import pytest
 from gemseo.algos.opt.core.linear_constraints import build_bounds_matrices
 from gemseo.algos.opt.core.linear_constraints import build_constraints_matrices
 from gemseo.core.mdofunctions.mdo_function import MDOFunction
-from gemseo.core.mdofunctions.mdo_function import MDOLinearFunction
+from gemseo.core.mdofunctions.mdo_linear_function import MDOLinearFunction
 from numpy import allclose
 from numpy import arange
 from numpy import array
