@@ -42,9 +42,9 @@ DIRNAME = Path(__file__).parent
 FAIL_HDF = DIRNAME / "fail.hdf5"
 
 
-@pytest.fixture()
-def h5_file(tmp_path):
-    return h5py.File(tmp_path / "test.h5", "w")
+@pytest.fixture
+def h5_file(tmp_wd):
+    return h5py.File("test.h5", "w")
 
 
 def rel_err(to_test, ref):
@@ -167,8 +167,8 @@ def test_get_all_datanames():
     assert database.get_all_data_names(True, True) == [fname]
     assert database.get_all_data_names(False, True) == [gname, fname]
 
-    assert database.get_all_data_names(True, False) == [database.ITER_TAG, fname]
-    assert database.get_all_data_names(False, False) == [
+    assert database.get_all_data_names() == [database.ITER_TAG, fname]
+    assert database.get_all_data_names(False) == [
         gname,
         database.ITER_TAG,
         fname,
@@ -218,7 +218,7 @@ def test_clean_from_iterate(problem):
     assert len(database) == 13
     # Add another point that cannot already exists
     x_test = array([10.0, -100.0])
-    database.store(x_test, {}, add_iter=True)
+    database.store(x_test, {})
     # Make sure that the iter tag is correct
     iter_id = int(database.get_f_of_x(Database.ITER_TAG, x_test)[0])
     assert iter_id, len(database)
@@ -245,14 +245,14 @@ def test_scipy_df0_rosenbrock(problem_and_result):
     database = problem.database
     assert result.f_opt < 6.5e-11
     assert norm(database.get_x_history()[-1] - ones(2)) < 2e-5
-    assert database.get_func_history(funcname="rosen", x_hist=False)[-1] < 6.2e-11
+    assert database.get_func_history(funcname="rosen")[-1] < 6.2e-11
 
 
 def test_append_export(tmp_wd):
     database = Database()
     file_path_db = "test_db_append.hdf5"
     # Export empty file
-    database.export_hdf(file_path_db, append=False)
+    database.export_hdf(file_path_db)
     val = {"f": arange(2)}
     n_calls = 200
     for i in range(n_calls):
@@ -278,23 +278,22 @@ def test_add_listeners():
         database.add_new_iter_listener("toto")
 
 
-def test_append_export_after_store(tmp_path):
+def test_append_export_after_store(tmp_wd):
     """Test that a database is correctly exported when it is appended after each storage
     call."""
-
     database = Database()
-    file_path_db = tmp_path / "test_db_append.hdf5"
+    file_path_db = "test_db_append.hdf5"
     val1 = {"f": arange(2)}
     val2 = {"g": 10}
     val3 = {"@f": array([[100], [200]])}
     n_calls = 50
     for i in range(n_calls):
         idx = array([i, i + 1])
-        database.store(idx, values_dict=val1, add_iter=True)
+        database.store(idx, values_dict=val1)
         database.export_hdf(file_path_db, append=True)
-        database.store(idx, values_dict=val2, add_iter=True)
+        database.store(idx, values_dict=val2)
         database.export_hdf(file_path_db, append=True)
-        database.store(idx, values_dict=val3, add_iter=True)
+        database.store(idx, values_dict=val3)
         database.export_hdf(file_path_db, append=True)
 
     new_database = Database(file_path_db)
@@ -399,11 +398,7 @@ def test_add_hdf_output_dataset(h5_file):
     values_group = h5_file.require_group("v")
     keys_group = h5_file.require_group("k")
 
-    values = {}
-    values["f"] = 10
-    values["g"] = array([1, 2])
-    values["Iter"] = [3]
-    values["@f"] = array([[1, 2, 3]])
+    values = {"f": 10, "g": array([1, 2]), "Iter": [3], "@f": array([[1, 2, 3]])}
     database._add_hdf_output_dataset(10, keys_group, values_group, values)
     assert list(keys_group["10"]) == list(array(list(values.keys()), dtype=string_))
     assert array(values_group["10"]) == pytest.approx(array([10]))
@@ -411,12 +406,13 @@ def test_add_hdf_output_dataset(h5_file):
     assert array(values_group["arr_10"]["2"]) == pytest.approx(array([3]))
     assert array(values_group["arr_10"]["3"]) == pytest.approx(array([[1, 2, 3]]))
 
-    values = {}
-    values["i"] = array([1, 2])
-    values["Iter"] = 1
-    values["@j"] = array([[1, 2, 3]])
-    values["k"] = 99
-    values["l"] = 100
+    values = {
+        "i": array([1, 2]),
+        "Iter": 1,
+        "@j": array([[1, 2, 3]]),
+        "k": 99,
+        "l": 100,
+    }
     database._add_hdf_output_dataset(100, keys_group, values_group, values)
     assert list(keys_group["100"]) == list(array(list(values.keys()), dtype=string_))
     assert array(values_group["100"]) == pytest.approx(array([1, 99, 100]))
@@ -431,34 +427,27 @@ def test_get_missing_hdf_output_dataset(h5_file):
     values_group = h5_file.require_group("v")
     keys_group = h5_file.require_group("k")
 
-    values = {"f": 0.1}
-    values["g"] = array([1, 2])
+    values = {"f": 0.1, "g": array([1, 2])}
     database._add_hdf_output_dataset(10, keys_group, values_group, values)
 
     with pytest.raises(ValueError):
         database._get_missing_hdf_output_dataset(0, keys_group, values)
 
-    values = {"f": 0.1}
-    values["g"] = array([1, 2])
-    values["h"] = [10]
+    values = {"f": 0.1, "g": array([1, 2]), "h": [10]}
     new_values, idx_mapping = database._get_missing_hdf_output_dataset(
         10, keys_group, values
     )
     assert new_values == {"h": [10]}
     assert idx_mapping == {"h": 2}
 
-    values = {"f": 0.1}
-    values["g"] = array([1, 2])
+    values = {"f": 0.1, "g": array([1, 2])}
     new_values, idx_mapping = database._get_missing_hdf_output_dataset(
         10, keys_group, values
     )
     assert new_values == {}
     assert idx_mapping is None
 
-    values = {"f": 0.1}
-    values["g"] = array([1, 2])
-    values["h"] = [2, 3]
-    values["i"] = 20
+    values = {"f": 0.1, "g": array([1, 2]), "h": [2, 3], "i": 20}
     new_values, idx_mapping = database._get_missing_hdf_output_dataset(
         10, keys_group, values
     )
@@ -499,9 +488,9 @@ def test_get_history_array(problem):
 
 def test_ggobi_export(tmp_wd, problem):
     """Tests export to GGobi."""
-    file_path = tmp_wd / "opt_hist.xml"
+    file_path = "opt_hist.xml"
     problem.database.export_to_ggobi(file_path=file_path)
-    assert file_path.exists()
+    assert Path(file_path).exists()
 
 
 def test_hdf_grad_export(tmp_wd, problem):
@@ -551,7 +540,7 @@ def test_opendace_import(tmp_wd):
     database = Database()
     inf = DIRNAME / "rae2822_cl075_085_mach_068_074.xml"
     database.import_from_opendace(inf)
-    outfpath = tmp_wd / "rae2822_cl075_085_mach_068_074_cp.hdf5"
+    outfpath = Path("rae2822_cl075_085_mach_068_074_cp.hdf5")
     database.export_hdf(outfpath)
     assert outfpath.exists()
 
@@ -563,9 +552,8 @@ def test_duplicates():
     x_vect = array([1.9, 8.9])
     value = rosen(x_vect)
     gradient = rosen_der(x_vect)
-    values_dict = {"Rosenbrock": value, "@Rosenbrock": gradient}
+    values_dict = {"Rosenbrock": value, "@Rosenbrock": gradient, "Iter^2": [1]}
     # Insert the point twice with stacked data (e.g. 'Iter_squared'):
-    values_dict["Iter^2"] = [1]
     database.store(x_vect, values_dict)
     values_dict["Iter^2"] = [1, 4]
     database.store(x_vect, values_dict)
@@ -598,9 +586,7 @@ def test_missing_tag():
     database.store(array([1.0, 1.0]), {"Rosenbrock": 0.0})
     # Check that a missing tag is added during history extraction:
     functions = ["Rosenbrock", Database.get_gradient_name("Rosenbrock")]
-    f_history, _ = database.get_complete_history(
-        functions, add_missing_tag=True, missing_tag="NA"
-    )
+    f_history, _ = database.get_complete_history(functions, add_missing_tag=True)
     assert f_history == [[value, gradient], [0.0, "NA"]]
 
 
@@ -733,9 +719,11 @@ def test_notify_newiter_store_listeners():
 
 @pytest.fixture
 def simple_database():
-    """A database with a single element: ([0.], {'y': 1.})."""
+    """A database with a single element."""
     database = Database()
-    database.store(array([0.0]), {"y": 1.0})
+    database.store(
+        array([0.0]), {"w": 1.0, "x": [2], "y": array([3.0]), "z": array([4.0, 5.0])}
+    )
     return database
 
 
@@ -751,4 +739,12 @@ def test_clear(simple_database, reset_iteration_counter, max_iteration):
 
 def test_last_item(simple_database):
     """Check that the property last_item is the last item stored in the database."""
-    assert simple_database.last_item["y"] == 1.0
+    assert simple_database.last_item["y"] == 3.0
+
+
+def test_get_history_array_with_simple_database(simple_database):
+    """Check get_history_array with a simple database."""
+    values_array, variables_names, functions = simple_database.get_history_array()
+    assert_almost_equal(values_array, array([[1.0, 1.0, 2.0, 3.0, 4.0, 5.0, 0.0]]))
+    assert variables_names == ["Iter", "w", "x", "y", "z (0)", "z (1)", "x_1"]
+    assert functions == ["Iter", "w", "x", "y", "z"]
