@@ -39,6 +39,7 @@ from numpy import nan
 from numpy import ones
 from numpy import savetxt
 from numpy import zeros
+from numpy.random import rand
 from numpy.testing import assert_equal
 
 
@@ -56,6 +57,16 @@ def dataset(data):
     return tmp
 
 
+@pytest.fixture
+def dataset_for_export_checking() -> Dataset:
+    "A dataset to check export_to_dataframe()." ""
+    dataset = Dataset()
+    dataset.add_variable("z", rand(5, 12), group="inputs")
+    dataset.add_variable("y", rand(5, 1), group="outputs")
+    dataset.add_variable("x", rand(5, 1), group="inputs")
+    return dataset
+
+
 @pytest.fixture
 def ungroup_dataset(data):
     variables = ["var_1", "var_2"]
@@ -79,14 +90,14 @@ def io_dataset():
 
 
 @pytest.fixture
-def file_dataset(tmp_path):
+def file_dataset(tmp_wd):
     inputs = arange(50).reshape(10, 5)
     outputs = arange(20).reshape(10, 2)
     data = concatenate([inputs, outputs], axis=1)
     variables = ["in_1", "in_2", "out_1"]
     sizes = {"in_1": 2, "in_2": 3, "out_1": 2}
     groups = {"in_1": "inputs", "in_2": "inputs", "out_1": "outputs"}
-    filename = tmp_path / "dataset.txt"
+    filename = "dataset.txt"
     savetxt(filename, data, delimiter=",")
     return filename, data, variables, sizes, groups
 
@@ -350,7 +361,7 @@ def test_add_group(dataset, ungroup_dataset):
         ungroup_dataset.add_group("grp10", arange(5).reshape(5, 1))
 
 
-def test_export_to_dataframe(dataset):
+def test_export_to_dataframe():
     """Check the dataframe resulting from a dataset export."""
     variables = ["i1", "o2", "o1", "i2"]
     sizes = {"i1": 1, "i2": 2, "o1": 1, "o2": 2}
@@ -373,6 +384,85 @@ def test_export_to_dataframe(dataset):
     assert_equal(df.values, array([[0, 4, 5, 3, 1, 2], [6, 10, 11, 9, 7, 8]]))
 
 
+@pytest.mark.parametrize(
+    "sort_name,expected_columns",
+    [
+        (
+            False,
+            [
+                ("inputs", "z", "0"),
+                ("inputs", "z", "1"),
+                ("inputs", "z", "2"),
+                ("inputs", "z", "3"),
+                ("inputs", "z", "4"),
+                ("inputs", "z", "5"),
+                ("inputs", "z", "6"),
+                ("inputs", "z", "7"),
+                ("inputs", "z", "8"),
+                ("inputs", "z", "9"),
+                ("inputs", "z", "10"),
+                ("inputs", "z", "11"),
+                ("inputs", "x", "0"),
+                ("outputs", "y", "0"),
+            ],
+        ),
+        (
+            True,
+            [
+                ("inputs", "x", "0"),
+                ("inputs", "z", "0"),
+                ("inputs", "z", "1"),
+                ("inputs", "z", "2"),
+                ("inputs", "z", "3"),
+                ("inputs", "z", "4"),
+                ("inputs", "z", "5"),
+                ("inputs", "z", "6"),
+                ("inputs", "z", "7"),
+                ("inputs", "z", "8"),
+                ("inputs", "z", "9"),
+                ("inputs", "z", "10"),
+                ("inputs", "z", "11"),
+                ("outputs", "y", "0"),
+            ],
+        ),
+        (
+            None,
+            [
+                ("inputs", "x", "0"),
+                ("inputs", "z", "0"),
+                ("inputs", "z", "1"),
+                ("inputs", "z", "2"),
+                ("inputs", "z", "3"),
+                ("inputs", "z", "4"),
+                ("inputs", "z", "5"),
+                ("inputs", "z", "6"),
+                ("inputs", "z", "7"),
+                ("inputs", "z", "8"),
+                ("inputs", "z", "9"),
+                ("inputs", "z", "10"),
+                ("inputs", "z", "11"),
+                ("outputs", "y", "0"),
+            ],
+        ),
+    ],
+)
+@pytest.mark.parametrize("variable_names", [None, ["z", "y", "x"]])
+def test_export_to_dataframe_with_ordering(
+    dataset_for_export_checking, sort_name, expected_columns, variable_names
+):
+    if sort_name is None:
+        df = dataset_for_export_checking.export_to_dataframe(
+            variable_names=variable_names
+        )
+    else:
+        df = dataset_for_export_checking.export_to_dataframe(
+            sort_names=sort_name, variable_names=variable_names
+        )
+
+    for column, expected_column in zip(df.columns, expected_columns):
+        assert column == expected_column
+
+
 def test_get_columns_names():
     """Check the default names of the dataset columns."""
     dataset = Dataset()
@@ -433,13 +523,13 @@ def test_n_samples(io_dataset):
 @pytest.mark.parametrize("cache_type", ["MemoryFullCache", "HDF5Cache"])
 @pytest.mark.parametrize("inputs", [None, ["var_1"]])
 @pytest.mark.parametrize("outputs", [None, ["var_2"]])
-def test_export_dataset_to_cache(dataset, tmp_path, cache_type, inputs, outputs):
+def test_export_dataset_to_cache(dataset, tmp_wd, cache_type, inputs, outputs):
     """Check that a dataset is correctly exported to a cache."""
     input_names = inputs or ["var_1", "var_2"]
     output_names = outputs or []
     cache = dataset.export_to_cache(
         cache_type=cache_type,
-        cache_hdf_file=str(tmp_path / "cache.hdf5"),
+        cache_hdf_file="cache.hdf5",
         inputs=inputs,
         outputs=outputs,
     )
@@ -538,9 +628,8 @@ def test_getitem_raising_error(x_dataset, item, error, msg):
         x_dataset[item]
 
 
-def test_plot(dataset, tmp_path):
-    fpath = tmp_path / "scatter"
-    post = dataset.plot("ScatterMatrix", show=False, save=True, file_path=fpath)
+def test_plot(dataset, tmp_wd):
+    post = dataset.plot("ScatterMatrix", show=False, save=True, file_path="scatter")
     assert len(post.output_files) > 0
     assert "ScatterMatrix" in dataset.get_available_plots()
 
@@ -613,7 +702,7 @@ def test_malformed_groups():
     dataset = Dataset()
     with pytest.raises(
         TypeError,
-        match=("groups must be a dictionary of the form {variable_name: group_name}."),
+        match="groups must be a dictionary of the form {variable_name: group_name}.",
     ):
         dataset.set_from_array(array([[1]]), variables=["x"], groups={"x": 1})
 
@@ -623,7 +712,7 @@ def test_malformed_variables():
     dataset = Dataset()
     with pytest.raises(
         TypeError,
-        match=("variables must be a list of string variable names."),
+        match="variables must be a list of string variable names.",
     ):
         dataset.set_from_array(array([[1]]), variables=1)
 
