@@ -44,13 +44,13 @@ def dataset() -> Dataset:
 def test_plot(dataset, pyplot_close_all):
     """Check the creation of a plot with subplots."""
     fig, (ax1, ax2) = plt.subplots(ncols=2)
-    plot_1 = BarPlot(dataset)
+    plot_1 = BarPlot(dataset, n_digits=2)
     plot_1.colormap = "PiYG"
     plot_1.title = "Plot 1"
-    plot_1.execute(save=False, show=False, fig=fig, axes=ax1)
+    plot_1.execute(save=False, fig=fig, axes=ax1)
     plot_2 = YvsX(dataset, "x2", "x3")
     plot_2.linestyle = "-d"
     plot_2.color = "r"
     plot_2.title = "Plot 2"
-    plot_2.execute(save=False, show=False, fig=fig, axes=ax2)
+    plot_2.execute(save=False, fig=fig, axes=ax2)
     fig.suptitle("Plots 1 and 2")
