@@ -43,12 +43,7 @@ def test_run(density_filter):
 
 def test_jacobian(density_filter):
     """Check the analytic Jacobian by finite differences."""
-
     input_data = density_filter.get_input_data()
     assert density_filter.check_jacobian(
-        input_data,
-        threshold=THRESHOLD,
-        derr_approx=density_filter.FINITE_DIFFERENCES,
-        step=1e-5,
-        auto_set_step=True,
+        input_data, threshold=THRESHOLD, step=1e-5, auto_set_step=True
     )
