@@ -52,7 +52,6 @@ def finite_element_analysis():
 @pytest.fixture(scope="module")
 def default_finite_element_analysis():
     """A finite element analysis."""
-
     return FininiteElementAnalysis()
 
 
@@ -76,8 +75,5 @@ def test_jacobian(finite_element_analysis):
     """Check the analytic Jacobian by finite differences."""
     indata = finite_element_analysis.get_input_data()
     assert finite_element_analysis.check_jacobian(
-        indata,
-        threshold=1e-5,
-        derr_approx=finite_element_analysis.FINITE_DIFFERENCES,
-        auto_set_step=True,
+        indata, threshold=1e-5, auto_set_step=True
     )
