@@ -16,6 +16,7 @@ from __future__ import annotations
 
 import runpy
 from pathlib import Path
+from re import findall
 from shutil import copytree
 
 import pytest
@@ -25,7 +26,8 @@ EXAMPLE_PATHS = [
     for path in Path(__file__, "..", "..", "doc_src", "_examples")
     .resolve()
     .rglob("*.py")
-    if (path.parent / "README.rst").is_file() and path.name != "run.py"
+    if (path.parent / "README.rst").is_file()
+    and not findall(r"(run|post_process_|save_from_)\w*\.py$", path.name)
 ]
 
 
@@ -34,7 +36,7 @@ EXAMPLE_PATHS = [
     "example_path", EXAMPLE_PATHS, ids=(path.name for path in EXAMPLE_PATHS)
 )
 def test_script_execution(example_path, tmp_wd, monkeypatch):
-    dir_path = tmp_wd / example_path.parent.name
+    dir_path = example_path.parent.name
     Path(copytree(example_path.parent, dir_path))
     monkeypatch.chdir(dir_path)
     runpy.run_path(example_path.name)
